import { OrgManagementClient } from './OrgManagementClient';
import { ManagementClientOptions } from './types';
import { UserPoolManagementClient } from './UserpoolManagementClient';
import { UsersManagementClient } from './UsersManagementClient';
import { EmailScene, User } from '../../types/graphql.v2';
import { RolesManagementClient } from './RolesManagementClient';
import { PoliciesManagementClient } from './PoliciesManagementClient';
import { UdfManagementClient } from './UdfManagementClient';
import { GroupsManagementClient } from './GroupsManagementClient';
import { AclManagementClient } from './AclManagementClient';
import { WhitelistManagementClient } from './WhitelistManagementClient';
import { StatisticsManagementClient } from './StatisticsManagementClient';
import { UserActionManagementClient } from './UserActionManagementClient';
import { ApplicationsManagementClient } from './ApplicationsManagementClient';
import { MFAManagementClient } from './MFAManagementClient';
export declare class ManagementClient {
    options: ManagementClientOptions;
    private graphqlClient;
    private httpClient;
    private tokenProvider;
    private publicKeyManager;
    users: UsersManagementClient;
    userpool: UserPoolManagementClient;
    acl: AclManagementClient;
    org: OrgManagementClient;
    roles: RolesManagementClient;
    policies: PoliciesManagementClient;
    udf: UdfManagementClient;
    groups: GroupsManagementClient;
    whitelist: WhitelistManagementClient;
    statistics: StatisticsManagementClient;
    userAction: UserActionManagementClient;
    applications: ApplicationsManagementClient;
    mfa: MFAManagementClient;
    constructor(options: ManagementClientOptions);
    /**
     * @description send email
     * @param email: email
     * @param scene: scene
     *
     */
    sendEmail(email: string, scene: EmailScene): Promise<{
        message?: string;
        code?: number;
    }>;
    /**
     * @description check status of login
     *
     */
    checkLoginStatus(token: string, options?: {
        fetchUserDetail?: boolean;
    }): Promise<User>;
    /**
     * @name isPasswordValid
     * @name_zh Check if the password is legal
     * @description Check if the password is legal
     *
     * @param {string} password password
     *
     * @example
     *
     * const envList = await managementClient.isPasswordValid('xxxxxx')
     *
     * @returns {Promise<{
     *  valid: boolean
     *  message: string
     * }>} Return test result
     * @memberof ManagementClient
     */
    isPasswordValid(password: string): Promise<{
        valid: boolean;
        message: string;
    }[]>;
}
