import { AdminLogsInfo, ManagementClientOptions, UserLogsInfo } from './types';
import { ManagementTokenProvider } from './ManagementTokenProvider';
import { HttpClient } from '../common/HttpClient';
/**
 * @class StatisticsManagementClient Manage log statistics
 * @name StatisticsManagementClient
 * @description Manage log statistics
 *
 * @example
 *
 * Please use the module in the following ways:
 * \`\`\`javascript
 * import { StatisticsManagementClient } from "appow-js-sdk"
 * const managementClient = new ManagementClient({
 *    userPoolId: "YOUR_USERPOOL_ID",
 *    secret: "YOUR_USERPOOL_SECRET",
 * })
 * managementClient.statistics.listUserActions // View user operation log
 * managementClient.statistics.listAuditLogs // View audit log
 * \`\`\`
 *
 */
export declare class StatisticsManagementClient {
    options: ManagementClientOptions;
    httpClient: HttpClient;
    tokenProvider: ManagementTokenProvider;
    constructor(options: ManagementClientOptions, httpClient: HttpClient, tokenProvider: ManagementTokenProvider);
    /**
     * View user operation log
     * @param options.operationNames SupportedUserActionEnum
     */
    listUserActions(options?: {
        clientIp?: string;
        operationNames?: string[];
        userIds?: string[];
        page?: number;
        limit?: number;
    }): Promise<{
        totalCount: number;
        list: UserLogsInfo[];
    }>;
    /**
     * View audit log
     * @param options.operationNames  SupportedAdminActionEnum
     */
    listAuditLogs(options?: {
        clientIp?: string;
        operationNames?: string[];
        operatorArns?: string[];
        page?: number;
        limit?: number;
    }): Promise<{
        list: AdminLogsInfo[];
        totalCount: number;
    }>;
}
