import { ManagementClientOptions, UserActions } from './types';
import { ManagementTokenProvider } from './ManagementTokenProvider';
import { HttpClient } from '../common/HttpClient';
/**
 * @class UserActionManagementClient Audit management
 * @name UserActionManagementClient
 * @description Application management
 *
 * @example
 *
 * Please use the module in the following ways:
 * \`\`\`javascript
 * import { UserActionManagementClient } from "appow-js-sdk"
 * const managementClient = new ManagementClient({
 *    userPoolId: "YOUR_USERPOOL_ID",
 *    secret: "YOUR_USERPOOL_SECRET",
 * })
 * managementClient.userAction.list    // List query
 * managementClient.userAction.export // export log
 * \`\`\`
 *
 */
export declare class UserActionManagementClient {
    options: ManagementClientOptions;
    httpClient: HttpClient;
    tokenProvider: ManagementTokenProvider;
    constructor(options: ManagementClientOptions, httpClient: HttpClient, tokenProvider: ManagementTokenProvider);
    /**
     * Audit log list
     * @param options.page current page number
     * @param options.limit Number of items displayed per page
     * @param options.clientIp Client IP address
     * @param options.operationName Operation type
     * @param options.operatoArn User Arn is obtained through searchUser method
     * @returns Promise<UserActions>
     */
    list(options?: {
        page?: number;
        limit?: number;
        clientIp?: string;
        operationName?: string;
        operatoArn?: string;
    }): Promise<UserActions>;
}
