export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: any;
}> = {
    [K in keyof T]: T[K];
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    Object: any;
};
export declare type Query = {
    isActionAllowed: Scalars['Boolean'];
    isActionDenied: Scalars['Boolean'];
    authorizedTargets?: Maybe<PaginatedAuthorizedTargets>;
    qiniuUptoken?: Maybe<Scalars['String']>;
    isDomainAvaliable?: Maybe<Scalars['Boolean']>;
    /** get definition of social login */
    socialConnection?: Maybe<SocialConnection>;
    /** get all definition of social login */
    socialConnections: Array<SocialConnection>;
    /** get social login config of current user pool */
    socialConnectionInstance: SocialConnectionInstance;
    /** get all social login config of current user pool */
    socialConnectionInstances: Array<SocialConnectionInstance>;
    emailTemplates: Array<EmailTemplate>;
    previewEmail: Scalars['String'];
    /** get function template */
    templateCode: Scalars['String'];
    function?: Maybe<Function>;
    functions: PaginatedFunctions;
    group?: Maybe<Group>;
    groups: PaginatedGroups;
    /** query MFA info */
    queryMfa?: Maybe<Mfa>;
    nodeById?: Maybe<Node>;
    /** query node through code  */
    nodeByCode?: Maybe<Node>;
    /** query detailed org info */
    org: Org;
    /** query org list in user pool */
    orgs: PaginatedOrgs;
    /** query child node list */
    childrenNodes: Array<Node>;
    rootNode: Node;
    isRootNode?: Maybe<Scalars['Boolean']>;
    searchNodes: Array<Node>;
    checkPasswordStrength: CheckPasswordStrengthResult;
    policy?: Maybe<Policy>;
    policies: PaginatedPolicies;
    policyAssignments: PaginatedPolicyAssignments;
    /** get list of resources authorized to an object */
    authorizedResources?: Maybe<PaginatedAuthorizedResources>;
    /** query role info through **code** */
    role?: Maybe<Role>;
    /** get role list */
    roles: PaginatedRoles;
    /** query udv of an entity */
    udv: Array<UserDefinedData>;
    /** query udv in the user pool */
    udf: Array<UserDefinedField>;
    /** query udv of multiple objects */
    udfValueBatch: Array<UserDefinedDataMap>;
    user?: Maybe<User>;
    userBatch: Array<User>;
    users: PaginatedUsers;
    /** archived user list */
    archivedUsers: PaginatedUsers;
    searchUser: PaginatedUsers;
    checkLoginStatus?: Maybe<JwtTokenStatus>;
    isUserExists?: Maybe<Scalars['Boolean']>;
    findUser?: Maybe<User>;
    /** query user pool detailed info */
    userpool: UserPool;
    /** query user pool list */
    userpools: PaginatedUserpool;
    userpoolTypes: Array<UserPoolType>;
    /** get accessToken, used in multiple functions, sucha as initial SDK */
    accessToken: AccessTokenRes;
    /** user pool register whitelist */
    whitelist: Array<WhiteList>;
};
export declare type QueryIsActionAllowedArgs = {
    resource: Scalars['String'];
    action: Scalars['String'];
    userId: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type QueryIsActionDeniedArgs = {
    resource: Scalars['String'];
    action: Scalars['String'];
    userId: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type QueryAuthorizedTargetsArgs = {
    namespace: Scalars['String'];
    resourceType: ResourceType;
    resource: Scalars['String'];
    targetType?: Maybe<PolicyAssignmentTargetType>;
    actions?: Maybe<AuthorizedTargetsActionsInput>;
};
export declare type QueryQiniuUptokenArgs = {
    type?: Maybe<Scalars['String']>;
};
export declare type QueryIsDomainAvaliableArgs = {
    domain: Scalars['String'];
};
export declare type QuerySocialConnectionArgs = {
    provider: Scalars['String'];
};
export declare type QuerySocialConnectionInstanceArgs = {
    provider: Scalars['String'];
};
export declare type QueryPreviewEmailArgs = {
    type: EmailTemplateType;
};
export declare type QueryFunctionArgs = {
    id?: Maybe<Scalars['String']>;
};
export declare type QueryFunctionsArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
};
export declare type QueryGroupArgs = {
    code: Scalars['String'];
};
export declare type QueryGroupsArgs = {
    userId?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
};
export declare type QueryQueryMfaArgs = {
    id?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    userPoolId?: Maybe<Scalars['String']>;
};
export declare type QueryNodeByIdArgs = {
    id: Scalars['String'];
};
export declare type QueryNodeByCodeArgs = {
    orgId: Scalars['String'];
    code: Scalars['String'];
};
export declare type QueryOrgArgs = {
    id: Scalars['String'];
};
export declare type QueryOrgsArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
};
export declare type QueryChildrenNodesArgs = {
    orgId: Scalars['String'];
    nodeId: Scalars['String'];
};
export declare type QueryRootNodeArgs = {
    orgId: Scalars['String'];
};
export declare type QueryIsRootNodeArgs = {
    nodeId: Scalars['String'];
    orgId: Scalars['String'];
};
export declare type QuerySearchNodesArgs = {
    keyword: Scalars['String'];
};
export declare type QueryCheckPasswordStrengthArgs = {
    password: Scalars['String'];
};
export declare type QueryPolicyArgs = {
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type QueryPoliciesArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    namespace?: Maybe<Scalars['String']>;
    excludeDefault?: Maybe<Scalars['Boolean']>;
};
export declare type QueryPolicyAssignmentsArgs = {
    namespace?: Maybe<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
    targetType?: Maybe<PolicyAssignmentTargetType>;
    targetIdentifier?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
};
export declare type QueryAuthorizedResourcesArgs = {
    targetType?: Maybe<PolicyAssignmentTargetType>;
    targetIdentifier?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
};
export declare type QueryRoleArgs = {
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type QueryRolesArgs = {
    namespace?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
};
export declare type QueryUdvArgs = {
    targetType: UdfTargetType;
    targetId: Scalars['String'];
};
export declare type QueryUdfArgs = {
    targetType: UdfTargetType;
};
export declare type QueryUdfValueBatchArgs = {
    targetType: UdfTargetType;
    targetIds: Array<Maybe<Scalars['String']>>;
};
export declare type QueryUserArgs = {
    id?: Maybe<Scalars['String']>;
};
export declare type QueryUserBatchArgs = {
    ids: Array<Scalars['String']>;
};
export declare type QueryUsersArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
};
export declare type QueryArchivedUsersArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
};
export declare type QuerySearchUserArgs = {
    query: Scalars['String'];
    fields?: Maybe<Array<Maybe<Scalars['String']>>>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    departmentOpts?: Maybe<Array<Maybe<SearchUserDepartmentOpt>>>;
    groupOpts?: Maybe<Array<Maybe<SearchUserGroupOpt>>>;
    roleOpts?: Maybe<Array<Maybe<SearchUserRoleOpt>>>;
};
export declare type QueryCheckLoginStatusArgs = {
    token?: Maybe<Scalars['String']>;
};
export declare type QueryIsUserExistsArgs = {
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    externalId?: Maybe<Scalars['String']>;
};
export declare type QueryFindUserArgs = {
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    externalId?: Maybe<Scalars['String']>;
};
export declare type QueryUserpoolsArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
};
export declare type QueryAccessTokenArgs = {
    userPoolId: Scalars['String'];
    secret: Scalars['String'];
};
export declare type QueryWhitelistArgs = {
    type: WhitelistType;
};
export declare enum ResourceType {
    Data = "DATA",
    Api = "API",
    Menu = "MENU",
    Ui = "UI",
    Button = "BUTTON"
}
export declare enum PolicyAssignmentTargetType {
    User = "USER",
    Role = "ROLE",
    Group = "GROUP",
    Org = "ORG",
    AkSk = "AK_SK"
}
export declare type AuthorizedTargetsActionsInput = {
    op: Operator;
    list: Array<Maybe<Scalars['String']>>;
};
export declare enum Operator {
    And = "AND",
    Or = "OR"
}
export declare type PaginatedAuthorizedTargets = {
    list?: Maybe<Array<Maybe<ResourcePermissionAssignment>>>;
    totalCount?: Maybe<Scalars['Int']>;
};
export declare type ResourcePermissionAssignment = {
    targetType?: Maybe<PolicyAssignmentTargetType>;
    targetIdentifier?: Maybe<Scalars['String']>;
    actions?: Maybe<Array<Scalars['String']>>;
};
export declare type SocialConnection = {
    /** unique tag of social IDP */
    provider: Scalars['String'];
    /** name */
    name: Scalars['String'];
    /** logo */
    logo: Scalars['String'];
    /** description */
    description?: Maybe<Scalars['String']>;
    /** form field */
    fields?: Maybe<Array<SocialConnectionField>>;
};
export declare type SocialConnectionField = {
    key?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
    placeholder?: Maybe<Scalars['String']>;
    children?: Maybe<Array<Maybe<SocialConnectionField>>>;
};
export declare type SocialConnectionInstance = {
    provider: Scalars['String'];
    enabled: Scalars['Boolean'];
    fields?: Maybe<Array<Maybe<SocialConnectionInstanceField>>>;
};
export declare type SocialConnectionInstanceField = {
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type EmailTemplate = {
    /** email template type */
    type: EmailTemplateType;
    /** template name */
    name: Scalars['String'];
    /** email subject */
    subject: Scalars['String'];
    /** show email sender */
    sender: Scalars['String'];
    /** email template content */
    content: Scalars['String'];
    /** redirect link. After operating successfully, user will be redirected to this URL. */
    redirectTo?: Maybe<Scalars['String']>;
    hasURL?: Maybe<Scalars['Boolean']>;
    /** OTP expire time (seconds) */
    expiresIn?: Maybe<Scalars['Int']>;
    /** whether to enable the custom template */
    enabled?: Maybe<Scalars['Boolean']>;
    /** whether this is the system default template */
    isSystem?: Maybe<Scalars['Boolean']>;
};
export declare enum EmailTemplateType {
    /** reset password confirmation */
    ResetPassword = "RESET_PASSWORD",
    /** reset password notification */
    PasswordResetedNotification = "PASSWORD_RESETED_NOTIFICATION",
    /** change password verification code */
    ChangePassword = "CHANGE_PASSWORD",
    /** Register-welcome email注册欢迎邮件 */
    Welcome = "WELCOME",
    /** Verify Email */
    VerifyEmail = "VERIFY_EMAIL",
    /** Change Email */
    ChangeEmail = "CHANGE_EMAIL"
}
/** function */
export declare type Function = {
    /** ID */
    id: Scalars['String'];
    /** function name */
    name: Scalars['String'];
    /**  source code */
    sourceCode: Scalars['String'];
    /** description */
    description?: Maybe<Scalars['String']>;
    /** url of cloud function */
    url?: Maybe<Scalars['String']>;
};
export declare enum SortByEnum {
    /** sort by create date (desc) */
    CreatedatDesc = "CREATEDAT_DESC",
    /** sort by create date (asc) */
    CreatedatAsc = "CREATEDAT_ASC",
    /** sort by update date (desc) */
    UpdatedatDesc = "UPDATEDAT_DESC",
    /** sort by update date (asc) */
    UpdatedatAsc = "UPDATEDAT_ASC"
}
export declare type PaginatedFunctions = {
    list: Array<Function>;
    totalCount: Scalars['Int'];
};
export declare type Group = {
    /** unique tag: code */
    code: Scalars['String'];
    /** name */
    name: Scalars['String'];
    /** description */
    description?: Maybe<Scalars['String']>;
    /** create time */
    createdAt?: Maybe<Scalars['String']>;
    /** update time */
    updatedAt?: Maybe<Scalars['String']>;
    /** group user list */
    users: PaginatedUsers;
    /** all authorized resources */
    authorizedResources?: Maybe<PaginatedAuthorizedResources>;
};
export declare type GroupUsersArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
};
export declare type GroupAuthorizedResourcesArgs = {
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
};
export declare type PaginatedUsers = {
    totalCount: Scalars['Int'];
    list: Array<User>;
};
export declare type User = {
    /** user ID */
    id: Scalars['String'];
    arn: Scalars['String'];
    /** status of the user in the org */
    status?: Maybe<UserStatus>;
    /** user pool ID */
    userPoolId: Scalars['String'];
    /** username, unique in the user pool */
    username?: Maybe<Scalars['String']>;
    /** email, unique in the user pool  */
    email?: Maybe<Scalars['String']>;
    /** whether the email has been verified */
    emailVerified?: Maybe<Scalars['Boolean']>;
    /** phone number, unique in user pool */
    phone?: Maybe<Scalars['String']>;
    /** whether the phone number is verified  */
    phoneVerified?: Maybe<Scalars['Boolean']>;
    unionid?: Maybe<Scalars['String']>;
    openid?: Maybe<Scalars['String']>;
    /** user's identity info */
    identities?: Maybe<Array<Maybe<Identity>>>;
    /** nickname, not unique  */
    nickname?: Maybe<Scalars['String']>;
    /** register source */
    registerSource?: Maybe<Array<Scalars['String']>>;
    /** avatar link, default value is: https://usercontents.approw.com/approw-avatar.png */
    photo?: Maybe<Scalars['String']>;
    /** User password. In DB the password is encrypted by adding salt instead of storing plain text. */
    password?: Maybe<Scalars['String']>;
    /** Social register user's original info returned by third party IDP.
     * This field is empty for users who don't register through social IDP. */
    oauth?: Maybe<Scalars['String']>;
    /** User login token. Developer can validate the token in backend to authenticate the user. See：[validate Token](https://docs.approw.co/advanced/verify-jwt-token.html) */
    token?: Maybe<Scalars['String']>;
    /** token expire time */
    tokenExpiredAt?: Maybe<Scalars['String']>;
    /** user login count */
    loginsCount?: Maybe<Scalars['Int']>;
    /** user last login time */
    lastLogin?: Maybe<Scalars['String']>;
    /** user last login IP */
    lastIP?: Maybe<Scalars['String']>;
    /** user register time */
    signedUp?: Maybe<Scalars['String']>;
    /** whether the account is blocked */
    blocked?: Maybe<Scalars['Boolean']>;
    /** whether the account is deleted */
    isDeleted?: Maybe<Scalars['Boolean']>;
    device?: Maybe<Scalars['String']>;
    browser?: Maybe<Scalars['String']>;
    company?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    middleName?: Maybe<Scalars['String']>;
    profile?: Maybe<Scalars['String']>;
    preferredUsername?: Maybe<Scalars['String']>;
    website?: Maybe<Scalars['String']>;
    gender?: Maybe<Scalars['String']>;
    birthdate?: Maybe<Scalars['String']>;
    zoneinfo?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    formatted?: Maybe<Scalars['String']>;
    streetAddress?: Maybe<Scalars['String']>;
    locality?: Maybe<Scalars['String']>;
    region?: Maybe<Scalars['String']>;
    postalCode?: Maybe<Scalars['String']>;
    city?: Maybe<Scalars['String']>;
    province?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['String']>;
    /** user's role list */
    roles?: Maybe<PaginatedRoles>;
    /** user's group list */
    groups?: Maybe<PaginatedGroups>;
    /** user's department list */
    departments?: Maybe<PaginatedDepartments>;
    /** all authorized resources of the user */
    authorizedResources?: Maybe<PaginatedAuthorizedResources>;
    /** user external ID */
    externalId?: Maybe<Scalars['String']>;
};
export declare type UserRolesArgs = {
    namespace?: Maybe<Scalars['String']>;
};
export declare type UserDepartmentsArgs = {
    orgId?: Maybe<Scalars['String']>;
};
export declare type UserAuthorizedResourcesArgs = {
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
};
export declare enum UserStatus {
    /** suspended */
    Suspended = "Suspended",
    /** resigned */
    Resigned = "Resigned",
    /** activated (normal) */
    Activated = "Activated",
    /** archived */
    Archived = "Archived"
}
export declare type Identity = {
    openid?: Maybe<Scalars['String']>;
    userIdInIdp?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    connectionId?: Maybe<Scalars['String']>;
    isSocial?: Maybe<Scalars['Boolean']>;
    provider?: Maybe<Scalars['String']>;
    userPoolId?: Maybe<Scalars['String']>;
    refreshToken?: Maybe<Scalars['String']>;
    accessToken?: Maybe<Scalars['String']>;
};
export declare type PaginatedRoles = {
    totalCount: Scalars['Int'];
    list: Array<Role>;
};
export declare type Role = {
    /** privilege group code */
    namespace: Scalars['String'];
    /** unique tag code */
    code: Scalars['String'];
    /** resource identifier: arn */
    arn: Scalars['String'];
    /** role description */
    description?: Maybe<Scalars['String']>;
    /** Whether this is a system built-in role (can't be deleted) */
    isSystem?: Maybe<Scalars['Boolean']>;
    /** create time */
    createdAt?: Maybe<Scalars['String']>;
    /** update time */
    updatedAt?: Maybe<Scalars['String']>;
    /** list of users who are granted with this role */
    users: PaginatedUsers;
    /** all resources authorized to access */
    authorizedResources?: Maybe<PaginatedAuthorizedResources>;
    /** parent role */
    parent?: Maybe<Role>;
};
export declare type RoleAuthorizedResourcesArgs = {
    resourceType?: Maybe<Scalars['String']>;
};
export declare type PaginatedAuthorizedResources = {
    totalCount: Scalars['Int'];
    list: Array<AuthorizedResource>;
};
export declare type AuthorizedResource = {
    code: Scalars['String'];
    type?: Maybe<ResourceType>;
    actions?: Maybe<Array<Scalars['String']>>;
};
export declare type PaginatedGroups = {
    totalCount: Scalars['Int'];
    list: Array<Group>;
};
export declare type PaginatedDepartments = {
    list: Array<UserDepartment>;
    totalCount: Scalars['Int'];
};
export declare type UserDepartment = {
    department: Node;
    /** Whether this is the main department */
    isMainDepartment: Scalars['Boolean'];
    /** when did the user join this department */
    joinedAt?: Maybe<Scalars['String']>;
};
export declare type Node = {
    id: Scalars['String'];
    /** org ID */
    orgId?: Maybe<Scalars['String']>;
    /** node name */
    name: Scalars['String'];
    /** multi-language name, **key** is **i18n** language code, **value** is the name of the language. */
    nameI18n?: Maybe<Scalars['String']>;
    /** description info */
    description?: Maybe<Scalars['String']>;
    /** multi-language description */
    descriptionI18n?: Maybe<Scalars['String']>;
    /** Order number in parent node. The node with higher **order** value is in the front. Value range: [0, 2^32) */
    order?: Maybe<Scalars['Int']>;
    /** Node unique tag. Can search node through code. */
    code?: Maybe<Scalars['String']>;
    /** Whether the node is root node. */
    root?: Maybe<Scalars['Boolean']>;
    /** Distance to parent node.
     * (If query the whole tree, returned **depth** is distance to root node.
     * If query a child node of a node, the returned **depth** is the distance to parent node.) */
    depth?: Maybe<Scalars['Int']>;
    path: Array<Scalars['String']>;
    codePath: Array<Maybe<Scalars['String']>>;
    namePath: Array<Scalars['String']>;
    createdAt?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['String']>;
    /** child node's **ID** list of this node */
    children?: Maybe<Array<Scalars['String']>>;
    /** user list of the node */
    users: PaginatedUsers;
    /** all authorized resources */
    authorizedResources?: Maybe<PaginatedAuthorizedResources>;
};
export declare type NodeUsersArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
    includeChildrenNodes?: Maybe<Scalars['Boolean']>;
};
export declare type NodeAuthorizedResourcesArgs = {
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
};
export declare type Mfa = {
    /** MFA ID */
    id: Scalars['String'];
    /** user ID */
    userId: Scalars['String'];
    /** user pool ID */
    userPoolId: Scalars['String'];
    /** Whether MFA is enabled */
    enable: Scalars['Boolean'];
    /** secret */
    secret?: Maybe<Scalars['String']>;
};
export declare type Org = {
    /** org ID */
    id: Scalars['String'];
    /** root node */
    rootNode: Node;
    /** org node list */
    nodes: Array<Node>;
};
export declare type PaginatedOrgs = {
    totalCount: Scalars['Int'];
    list: Array<Org>;
};
export declare type CheckPasswordStrengthResult = {
    valid: Scalars['Boolean'];
    message?: Maybe<Scalars['String']>;
};
export declare type Policy = {
    /** privilege group code */
    namespace: Scalars['String'];
    code: Scalars['String'];
    isDefault: Scalars['Boolean'];
    description?: Maybe<Scalars['String']>;
    statements: Array<PolicyStatement>;
    createdAt?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['String']>;
    /** assignment/authorization count */
    assignmentsCount: Scalars['Int'];
    /** assignment/authorization records */
    assignments: Array<PolicyAssignment>;
};
export declare type PolicyAssignmentsArgs = {
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type PolicyStatement = {
    resource: Scalars['String'];
    actions: Array<Scalars['String']>;
    effect?: Maybe<PolicyEffect>;
    condition?: Maybe<Array<PolicyStatementCondition>>;
};
export declare enum PolicyEffect {
    Allow = "ALLOW",
    Deny = "DENY"
}
export declare type PolicyStatementCondition = {
    param: Scalars['String'];
    operator: Scalars['String'];
    value: Scalars['Object'];
};
export declare type PolicyAssignment = {
    code: Scalars['String'];
    targetType: PolicyAssignmentTargetType;
    targetIdentifier: Scalars['String'];
};
export declare type PaginatedPolicies = {
    totalCount: Scalars['Int'];
    list: Array<Policy>;
};
export declare type PaginatedPolicyAssignments = {
    totalCount: Scalars['Int'];
    list: Array<PolicyAssignment>;
};
export declare enum UdfTargetType {
    Node = "NODE",
    Org = "ORG",
    User = "USER",
    Userpool = "USERPOOL",
    Role = "ROLE",
    Permission = "PERMISSION",
    Application = "APPLICATION"
}
export declare type UserDefinedData = {
    key: Scalars['String'];
    dataType: UdfDataType;
    value: Scalars['String'];
    label?: Maybe<Scalars['String']>;
};
export declare enum UdfDataType {
    String = "STRING",
    Number = "NUMBER",
    Datetime = "DATETIME",
    Boolean = "BOOLEAN",
    Object = "OBJECT"
}
export declare type UserDefinedField = {
    targetType: UdfTargetType;
    dataType: UdfDataType;
    key: Scalars['String'];
    label?: Maybe<Scalars['String']>;
    options?: Maybe<Scalars['String']>;
};
export declare type UserDefinedDataMap = {
    targetId: Scalars['String'];
    data: Array<UserDefinedData>;
};
export declare type SearchUserDepartmentOpt = {
    departmentId?: Maybe<Scalars['String']>;
    includeChildrenDepartments?: Maybe<Scalars['Boolean']>;
};
export declare type SearchUserGroupOpt = {
    code?: Maybe<Scalars['String']>;
};
export declare type SearchUserRoleOpt = {
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
};
export declare type JwtTokenStatus = {
    code?: Maybe<Scalars['Int']>;
    message?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['Boolean']>;
    exp?: Maybe<Scalars['Int']>;
    iat?: Maybe<Scalars['Int']>;
    data?: Maybe<JwtTokenStatusDetail>;
};
export declare type JwtTokenStatusDetail = {
    id?: Maybe<Scalars['String']>;
    userPoolId?: Maybe<Scalars['String']>;
    arn?: Maybe<Scalars['String']>;
};
export declare type UserPool = {
    id: Scalars['String'];
    name: Scalars['String'];
    domain: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    secret: Scalars['String'];
    jwtSecret: Scalars['String'];
    ownerId?: Maybe<Scalars['String']>;
    userpoolTypes?: Maybe<Array<UserPoolType>>;
    logo: Scalars['String'];
    createdAt?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['String']>;
    /** Whether to verify the user's email (user's emailVerified field). Default value is false. */
    emailVerifiedDefault: Scalars['Boolean'];
    /** Whether to send welcome email after registering */
    sendWelcomeEmail: Scalars['Boolean'];
    /** Whether to disable register or not */
    registerDisabled: Scalars['Boolean'];
    /** Whether to enable SSO between apps in th same user pool */
    appSsoEnabled: Scalars['Boolean'];
    /**
     * Whether to keep showing WeChat Mini Program QR code login when user register is disabled. When **showWXMPQRCode** is **true**,
     * the frontend shows QR code. So at this time, only users who registered by QR code scanning before can login through QR code. New user can not login.
     */
    showWxQRCodeWhenRegisterDisabled?: Maybe<Scalars['Boolean']>;
    /** front CORS request whitelist */
    allowedOrigins?: Maybe<Scalars['String']>;
    /** user **token** valid time. In seconds. Default value is 15 days. */
    tokenExpiresAfter?: Maybe<Scalars['Int']>;
    /** Whether it is deleted */
    isDeleted?: Maybe<Scalars['Boolean']>;
    /** Frequently register check */
    frequentRegisterCheck?: Maybe<FrequentRegisterCheckConfig>;
    /** login failed check */
    loginFailCheck?: Maybe<LoginFailCheckConfig>;
    /** change phone strategy */
    changePhoneStrategy?: Maybe<ChangePhoneStrategy>;
    /** change email strategy */
    changeEmailStrategy?: Maybe<ChangeEmailStrategy>;
    /** APP QR code login strategy */
    qrcodeLoginStrategy?: Maybe<QrcodeLoginStrategy>;
    /** APP launch Mini Program login strategy */
    app2WxappLoginStrategy?: Maybe<App2WxappLoginStrategy>;
    /** registration whitelist configurations */
    whitelist?: Maybe<RegisterWhiteListConfig>;
    /** custom SMS Provider configuration */
    customSMSProvider?: Maybe<CustomSmsProvider>;
    /** user pool package type */
    packageType?: Maybe<Scalars['Int']>;
    /** Whether to use custom DB CUSTOM_USER_STORE mode */
    useCustomUserStore?: Maybe<Scalars['Boolean']>;
    /** Whether to require a verified email to login */
    loginRequireEmailVerified?: Maybe<Scalars['Boolean']>;
    /** SMS verification code length */
    verifyCodeLength?: Maybe<Scalars['Int']>;
};
export declare type UserPoolType = {
    code?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    image?: Maybe<Scalars['String']>;
    sdks?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type FrequentRegisterCheckConfig = {
    timeInterval?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    enabled?: Maybe<Scalars['Boolean']>;
};
export declare type LoginFailCheckConfig = {
    timeInterval?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    enabled?: Maybe<Scalars['Boolean']>;
};
export declare type ChangePhoneStrategy = {
    verifyOldPhone?: Maybe<Scalars['Boolean']>;
};
export declare type ChangeEmailStrategy = {
    verifyOldEmail?: Maybe<Scalars['Boolean']>;
};
export declare type QrcodeLoginStrategy = {
    qrcodeExpiresAfter?: Maybe<Scalars['Int']>;
    returnFullUserInfo?: Maybe<Scalars['Boolean']>;
    allowExchangeUserInfoFromBrowser?: Maybe<Scalars['Boolean']>;
    ticketExpiresAfter?: Maybe<Scalars['Int']>;
};
export declare type App2WxappLoginStrategy = {
    ticketExpriresAfter?: Maybe<Scalars['Int']>;
    ticketExchangeUserInfoNeedSecret?: Maybe<Scalars['Boolean']>;
};
export declare type RegisterWhiteListConfig = {
    /** whether to enable the phone number register whitelist */
    phoneEnabled?: Maybe<Scalars['Boolean']>;
    /** whether to enable the email register whitelist */
    emailEnabled?: Maybe<Scalars['Boolean']>;
    /** whether to enable the username register whitelist */
    usernameEnabled?: Maybe<Scalars['Boolean']>;
};
export declare type CustomSmsProvider = {
    enabled?: Maybe<Scalars['Boolean']>;
    provider?: Maybe<Scalars['String']>;
    config?: Maybe<Scalars['String']>;
};
export declare type PaginatedUserpool = {
    totalCount: Scalars['Int'];
    list: Array<UserPool>;
};
export declare type AccessTokenRes = {
    accessToken?: Maybe<Scalars['String']>;
    exp?: Maybe<Scalars['Int']>;
    iat?: Maybe<Scalars['Int']>;
};
export declare enum WhitelistType {
    Username = "USERNAME",
    Email = "EMAIL",
    Phone = "PHONE"
}
export declare type WhiteList = {
    createdAt?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['String']>;
    value: Scalars['String'];
};
export declare type Mutation = {
    /** allow to operate on some resource */
    allow: CommonMessage;
    /** authorize a resource to user/role/group/org. Can also specify different operation privileges. */
    authorizeResource: CommonMessage;
    /** config social login */
    createSocialConnectionInstance: SocialConnectionInstance;
    /** enable social login */
    enableSocialConnectionInstance: SocialConnectionInstance;
    /** disable social login */
    disableSocialConnectionInstance: SocialConnectionInstance;
    /** set the main department of a user in an org */
    setMainDepartment: CommonMessage;
    /** config custom email template */
    configEmailTemplate: EmailTemplate;
    /** enable custom email template */
    enableEmailTemplate: EmailTemplate;
    /** disable custom email template (will use system default email template instead) */
    disableEmailTemplate: EmailTemplate;
    /** send email */
    sendEmail: CommonMessage;
    /** create function */
    createFunction?: Maybe<Function>;
    /** update function */
    updateFunction: Function;
    deleteFunction: CommonMessage;
    addUserToGroup: CommonMessage;
    removeUserFromGroup: CommonMessage;
    /** */
    createGroup: Group;
    /**  */
    updateGroup: Group;
    /** bulk delete groups */
    deleteGroups: CommonMessage;
    loginByEmail?: Maybe<User>;
    loginByUsername?: Maybe<User>;
    loginByPhoneCode?: Maybe<User>;
    loginByPhonePassword?: Maybe<User>;
    /** update MFA info */
    changeMfa?: Maybe<Mfa>;
    /**  */
    createOrg: Org;
    /**  */
    deleteOrg: CommonMessage;
    /**  */
    addNode: Org;
    /**  */
    addNodeV2: Node;
    /**  */
    updateNode: Node;
    /** delete node (and all its child nodes) */
    deleteNode: CommonMessage;
    /** batch add members to a node */
    addMember: Node;
    /** batch remove members from a node */
    removeMember: Node;
    moveNode: Org;
    resetPassword?: Maybe<CommonMessage>;
    createPolicy: Policy;
    updatePolicy: Policy;
    deletePolicy: CommonMessage;
    deletePolicies: CommonMessage;
    addPolicyAssignments: CommonMessage;
    /**  */
    enablePolicyAssignment: CommonMessage;
    /**  */
    disbalePolicyAssignment: CommonMessage;
    removePolicyAssignments: CommonMessage;
    registerByUsername?: Maybe<User>;
    registerByEmail?: Maybe<User>;
    registerByPhoneCode?: Maybe<User>;
    /**  */
    createRole: Role;
    /**  */
    updateRole: Role;
    /**  */
    deleteRole: CommonMessage;
    /** bulk delete roles */
    deleteRoles: CommonMessage;
    /** assign roles to a user */
    assignRole?: Maybe<CommonMessage>;
    /** revoke roles from a user */
    revokeRole?: Maybe<CommonMessage>;
    /**  */
    loginBySubAccount: User;
    setUdf: UserDefinedField;
    removeUdf?: Maybe<CommonMessage>;
    setUdv?: Maybe<Array<UserDefinedData>>;
    setUdfValueBatch?: Maybe<CommonMessage>;
    removeUdv?: Maybe<Array<UserDefinedData>>;
    setUdvBatch?: Maybe<Array<UserDefinedData>>;
    refreshToken?: Maybe<RefreshToken>;
    /** Create user. This API requires admin privileges. For normal user registration, please use **register** API. */
    createUser: User;
    /** update user info */
    updateUser: User;
    /** Update user password directly. This API requires old password. For administrator, please use **updateUser** API. */
    updatePassword: User;
    /** Bind phone number. The current must not bind a phone number if you want to use this API. */
    bindPhone: User;
    /**  */
    bindEmail: User;
    /** Unbind phone number. Calling this API requires the current user has bound a phone number and another login method. */
    unbindPhone: User;
    /** Update phone number. This API requires verifying the SMS verification code. Administrators can update it directly through **updateUser** API. */
    updatePhone: User;
    /** Update email. This API requires verifying the email verification code. Administrators can update it directly through **updateUser** API. */
    updateEmail: User;
    /**  */
    unbindEmail: User;
    /**  */
    deleteUser?: Maybe<CommonMessage>;
    /** bulk delete users */
    deleteUsers?: Maybe<CommonMessage>;
    /**  */
    createUserpool: UserPool;
    updateUserpool: UserPool;
    refreshUserpoolSecret: Scalars['String'];
    deleteUserpool: CommonMessage;
    refreshAccessToken: RefreshAccessTokenRes;
    addWhitelist: Array<Maybe<WhiteList>>;
    removeWhitelist: Array<Maybe<WhiteList>>;
};
export declare type MutationAllowArgs = {
    resource: Scalars['String'];
    action: Scalars['String'];
    userId?: Maybe<Scalars['String']>;
    userIds?: Maybe<Array<Scalars['String']>>;
    roleCode?: Maybe<Scalars['String']>;
    roleCodes?: Maybe<Array<Scalars['String']>>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationAuthorizeResourceArgs = {
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<ResourceType>;
    resource?: Maybe<Scalars['String']>;
    opts?: Maybe<Array<Maybe<AuthorizeResourceOpt>>>;
};
export declare type MutationCreateSocialConnectionInstanceArgs = {
    input: CreateSocialConnectionInstanceInput;
};
export declare type MutationEnableSocialConnectionInstanceArgs = {
    provider: Scalars['String'];
};
export declare type MutationDisableSocialConnectionInstanceArgs = {
    provider: Scalars['String'];
};
export declare type MutationSetMainDepartmentArgs = {
    userId: Scalars['String'];
    departmentId?: Maybe<Scalars['String']>;
};
export declare type MutationConfigEmailTemplateArgs = {
    input: ConfigEmailTemplateInput;
};
export declare type MutationEnableEmailTemplateArgs = {
    type: EmailTemplateType;
};
export declare type MutationDisableEmailTemplateArgs = {
    type: EmailTemplateType;
};
export declare type MutationSendEmailArgs = {
    email: Scalars['String'];
    scene: EmailScene;
};
export declare type MutationCreateFunctionArgs = {
    input: CreateFunctionInput;
};
export declare type MutationUpdateFunctionArgs = {
    input: UpdateFunctionInput;
};
export declare type MutationDeleteFunctionArgs = {
    id: Scalars['String'];
};
export declare type MutationAddUserToGroupArgs = {
    userIds: Array<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
};
export declare type MutationRemoveUserFromGroupArgs = {
    userIds: Array<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
};
export declare type MutationCreateGroupArgs = {
    code: Scalars['String'];
    name: Scalars['String'];
    description?: Maybe<Scalars['String']>;
};
export declare type MutationUpdateGroupArgs = {
    code: Scalars['String'];
    name?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    newCode?: Maybe<Scalars['String']>;
};
export declare type MutationDeleteGroupsArgs = {
    codeList: Array<Scalars['String']>;
};
export declare type MutationLoginByEmailArgs = {
    input: LoginByEmailInput;
};
export declare type MutationLoginByUsernameArgs = {
    input: LoginByUsernameInput;
};
export declare type MutationLoginByPhoneCodeArgs = {
    input: LoginByPhoneCodeInput;
};
export declare type MutationLoginByPhonePasswordArgs = {
    input: LoginByPhonePasswordInput;
};
export declare type MutationChangeMfaArgs = {
    enable?: Maybe<Scalars['Boolean']>;
    id?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    userPoolId?: Maybe<Scalars['String']>;
    refresh?: Maybe<Scalars['Boolean']>;
};
export declare type MutationCreateOrgArgs = {
    name: Scalars['String'];
    code?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
};
export declare type MutationDeleteOrgArgs = {
    id: Scalars['String'];
};
export declare type MutationAddNodeArgs = {
    orgId: Scalars['String'];
    parentNodeId?: Maybe<Scalars['String']>;
    name: Scalars['String'];
    nameI18n?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    descriptionI18n?: Maybe<Scalars['String']>;
    order?: Maybe<Scalars['Int']>;
    code?: Maybe<Scalars['String']>;
};
export declare type MutationAddNodeV2Args = {
    orgId: Scalars['String'];
    parentNodeId?: Maybe<Scalars['String']>;
    name: Scalars['String'];
    nameI18n?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    descriptionI18n?: Maybe<Scalars['String']>;
    order?: Maybe<Scalars['Int']>;
    code?: Maybe<Scalars['String']>;
};
export declare type MutationUpdateNodeArgs = {
    id: Scalars['String'];
    name?: Maybe<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
};
export declare type MutationDeleteNodeArgs = {
    orgId: Scalars['String'];
    nodeId: Scalars['String'];
};
export declare type MutationAddMemberArgs = {
    nodeId?: Maybe<Scalars['String']>;
    orgId?: Maybe<Scalars['String']>;
    nodeCode?: Maybe<Scalars['String']>;
    userIds: Array<Scalars['String']>;
    isLeader?: Maybe<Scalars['Boolean']>;
};
export declare type MutationRemoveMemberArgs = {
    nodeId?: Maybe<Scalars['String']>;
    orgId?: Maybe<Scalars['String']>;
    nodeCode?: Maybe<Scalars['String']>;
    userIds: Array<Scalars['String']>;
};
export declare type MutationMoveNodeArgs = {
    orgId: Scalars['String'];
    nodeId: Scalars['String'];
    targetParentId: Scalars['String'];
};
export declare type MutationResetPasswordArgs = {
    phone?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    newPassword: Scalars['String'];
};
export declare type MutationCreatePolicyArgs = {
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    statements: Array<PolicyStatementInput>;
};
export declare type MutationUpdatePolicyArgs = {
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    statements?: Maybe<Array<PolicyStatementInput>>;
    newCode?: Maybe<Scalars['String']>;
};
export declare type MutationDeletePolicyArgs = {
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationDeletePoliciesArgs = {
    codeList: Array<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationAddPolicyAssignmentsArgs = {
    policies: Array<Scalars['String']>;
    targetType: PolicyAssignmentTargetType;
    targetIdentifiers?: Maybe<Array<Scalars['String']>>;
    inheritByChildren?: Maybe<Scalars['Boolean']>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationEnablePolicyAssignmentArgs = {
    policy: Scalars['String'];
    targetType: PolicyAssignmentTargetType;
    targetIdentifier: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationDisbalePolicyAssignmentArgs = {
    policy: Scalars['String'];
    targetType: PolicyAssignmentTargetType;
    targetIdentifier: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationRemovePolicyAssignmentsArgs = {
    policies: Array<Scalars['String']>;
    targetType: PolicyAssignmentTargetType;
    targetIdentifiers?: Maybe<Array<Scalars['String']>>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationRegisterByUsernameArgs = {
    input: RegisterByUsernameInput;
};
export declare type MutationRegisterByEmailArgs = {
    input: RegisterByEmailInput;
};
export declare type MutationRegisterByPhoneCodeArgs = {
    input: RegisterByPhoneCodeInput;
};
export declare type MutationCreateRoleArgs = {
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    parent?: Maybe<Scalars['String']>;
};
export declare type MutationUpdateRoleArgs = {
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    newCode?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationDeleteRoleArgs = {
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationDeleteRolesArgs = {
    codeList: Array<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
};
export declare type MutationAssignRoleArgs = {
    namespace?: Maybe<Scalars['String']>;
    roleCode?: Maybe<Scalars['String']>;
    roleCodes?: Maybe<Array<Maybe<Scalars['String']>>>;
    userIds?: Maybe<Array<Scalars['String']>>;
    groupCodes?: Maybe<Array<Scalars['String']>>;
    nodeCodes?: Maybe<Array<Scalars['String']>>;
};
export declare type MutationRevokeRoleArgs = {
    namespace?: Maybe<Scalars['String']>;
    roleCode?: Maybe<Scalars['String']>;
    roleCodes?: Maybe<Array<Maybe<Scalars['String']>>>;
    userIds?: Maybe<Array<Scalars['String']>>;
    groupCodes?: Maybe<Array<Scalars['String']>>;
    nodeCodes?: Maybe<Array<Scalars['String']>>;
};
export declare type MutationLoginBySubAccountArgs = {
    account: Scalars['String'];
    password: Scalars['String'];
    captchaCode?: Maybe<Scalars['String']>;
    clientIp?: Maybe<Scalars['String']>;
};
export declare type MutationSetUdfArgs = {
    targetType: UdfTargetType;
    key: Scalars['String'];
    dataType: UdfDataType;
    label: Scalars['String'];
    options?: Maybe<Scalars['String']>;
};
export declare type MutationRemoveUdfArgs = {
    targetType: UdfTargetType;
    key: Scalars['String'];
};
export declare type MutationSetUdvArgs = {
    targetType: UdfTargetType;
    targetId: Scalars['String'];
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type MutationSetUdfValueBatchArgs = {
    targetType: UdfTargetType;
    input: Array<SetUdfValueBatchInput>;
};
export declare type MutationRemoveUdvArgs = {
    targetType: UdfTargetType;
    targetId: Scalars['String'];
    key: Scalars['String'];
};
export declare type MutationSetUdvBatchArgs = {
    targetType: UdfTargetType;
    targetId: Scalars['String'];
    udvList?: Maybe<Array<UserDefinedDataInput>>;
};
export declare type MutationRefreshTokenArgs = {
    id?: Maybe<Scalars['String']>;
};
export declare type MutationCreateUserArgs = {
    userInfo: CreateUserInput;
    keepPassword?: Maybe<Scalars['Boolean']>;
};
export declare type MutationUpdateUserArgs = {
    id?: Maybe<Scalars['String']>;
    input: UpdateUserInput;
};
export declare type MutationUpdatePasswordArgs = {
    newPassword: Scalars['String'];
    oldPassword?: Maybe<Scalars['String']>;
};
export declare type MutationBindPhoneArgs = {
    phone: Scalars['String'];
    phoneCode: Scalars['String'];
};
export declare type MutationBindEmailArgs = {
    email: Scalars['String'];
    emailCode: Scalars['String'];
};
export declare type MutationUpdatePhoneArgs = {
    phone: Scalars['String'];
    phoneCode: Scalars['String'];
    oldPhone?: Maybe<Scalars['String']>;
    oldPhoneCode?: Maybe<Scalars['String']>;
};
export declare type MutationUpdateEmailArgs = {
    email: Scalars['String'];
    emailCode: Scalars['String'];
    oldEmail?: Maybe<Scalars['String']>;
    oldEmailCode?: Maybe<Scalars['String']>;
};
export declare type MutationDeleteUserArgs = {
    id: Scalars['String'];
};
export declare type MutationDeleteUsersArgs = {
    ids: Array<Scalars['String']>;
};
export declare type MutationCreateUserpoolArgs = {
    name: Scalars['String'];
    domain: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    logo?: Maybe<Scalars['String']>;
    userpoolTypes?: Maybe<Array<Scalars['String']>>;
};
export declare type MutationUpdateUserpoolArgs = {
    input: UpdateUserpoolInput;
};
export declare type MutationRefreshAccessTokenArgs = {
    accessToken?: Maybe<Scalars['String']>;
};
export declare type MutationAddWhitelistArgs = {
    type: WhitelistType;
    list: Array<Scalars['String']>;
};
export declare type MutationRemoveWhitelistArgs = {
    type: WhitelistType;
    list: Array<Scalars['String']>;
};
export declare type CommonMessage = {
    /** Readable API response. Please use business status code to judge whether it is a success. */
    message?: Maybe<Scalars['String']>;
    /**
     * Business status code (different from HTTP status code). Only 200 means success. See more detail：
     * [Approw error code list](https://docs.approw.co/advanced/error-code.html)
     */
    code?: Maybe<Scalars['Int']>;
};
export declare type AuthorizeResourceOpt = {
    targetType: PolicyAssignmentTargetType;
    targetIdentifier: Scalars['String'];
    actions?: Maybe<Array<Scalars['String']>>;
};
export declare type CreateSocialConnectionInstanceInput = {
    /** social login provider */
    provider: Scalars['String'];
    fields?: Maybe<Array<Maybe<CreateSocialConnectionInstanceFieldInput>>>;
};
export declare type CreateSocialConnectionInstanceFieldInput = {
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type ConfigEmailTemplateInput = {
    /**  */
    type: EmailTemplateType;
    /** template name */
    name: Scalars['String'];
    /** email subject */
    subject: Scalars['String'];
    /** shown email sender */
    sender: Scalars['String'];
    /** email template content */
    content: Scalars['String'];
    /** Redirect URL. After operating successfully the user will be redirected to this URL. */
    redirectTo?: Maybe<Scalars['String']>;
    hasURL?: Maybe<Scalars['Boolean']>;
    /** verification code expire time (in seconds) */
    expiresIn?: Maybe<Scalars['Int']>;
};
/** email using scene */
export declare enum EmailScene {
    /** Send reset password email. A verification code is included. */
    ResetPassword = "RESET_PASSWORD",
    /** Send verification email */
    VerifyEmail = "VERIFY_EMAIL",
    /** Send an email to change email address. A verification code is included. */
    ChangeEmail = "CHANGE_EMAIL",
    /** Send MFA verification email */
    MfaVerify = "MFA_VERIFY"
}
export declare type CreateFunctionInput = {
    /** function name */
    name: Scalars['String'];
    /** source code */
    sourceCode: Scalars['String'];
    /** description info */
    description?: Maybe<Scalars['String']>;
    /** cloud function url */
    url?: Maybe<Scalars['String']>;
};
export declare type UpdateFunctionInput = {
    /** ID */
    id: Scalars['String'];
    /** function name */
    name?: Maybe<Scalars['String']>;
    /**  */
    sourceCode?: Maybe<Scalars['String']>;
    /**  */
    description?: Maybe<Scalars['String']>;
    /** cloud function url */
    url?: Maybe<Scalars['String']>;
};
export declare type LoginByEmailInput = {
    email: Scalars['String'];
    password: Scalars['String'];
    /** CAPTCHA code */
    captchaCode?: Maybe<Scalars['String']>;
    /** Whether to create an account automatically if user doesn't exist. */
    autoRegister?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }>  */
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline. */
    context?: Maybe<Scalars['String']>;
};
export declare type LoginByUsernameInput = {
    username: Scalars['String'];
    password: Scalars['String'];
    /** CAPTCHA code */
    captchaCode?: Maybe<Scalars['String']>;
    /** Whether to create an account automatically if user doesn't exist */
    autoRegister?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }> */
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline. */
    context?: Maybe<Scalars['String']>;
};
export declare type LoginByPhoneCodeInput = {
    phone: Scalars['String'];
    code: Scalars['String'];
    /** Whether to create an account automatically if user doesn't exist */
    autoRegister?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }>  */
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline.  */
    context?: Maybe<Scalars['String']>;
};
export declare type LoginByPhonePasswordInput = {
    phone: Scalars['String'];
    password: Scalars['String'];
    /** CAPTCHA code */
    captchaCode?: Maybe<Scalars['String']>;
    /** Whether to create an account automatically if user doesn't exist */
    autoRegister?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }>*/
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline. */
    context?: Maybe<Scalars['String']>;
};
export declare type PolicyStatementInput = {
    resource: Scalars['String'];
    actions: Array<Scalars['String']>;
    effect?: Maybe<PolicyEffect>;
    condition?: Maybe<Array<PolicyStatementConditionInput>>;
};
export declare type PolicyStatementConditionInput = {
    param: Scalars['String'];
    operator: Scalars['String'];
    value: Scalars['Object'];
};
export declare type RegisterByUsernameInput = {
    username: Scalars['String'];
    password: Scalars['String'];
    profile?: Maybe<RegisterProfile>;
    forceLogin?: Maybe<Scalars['Boolean']>;
    generateToken?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }> */
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline. */
    context?: Maybe<Scalars['String']>;
};
export declare type RegisterProfile = {
    ip?: Maybe<Scalars['String']>;
    oauth?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    nickname?: Maybe<Scalars['String']>;
    company?: Maybe<Scalars['String']>;
    photo?: Maybe<Scalars['String']>;
    device?: Maybe<Scalars['String']>;
    browser?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    middleName?: Maybe<Scalars['String']>;
    profile?: Maybe<Scalars['String']>;
    preferredUsername?: Maybe<Scalars['String']>;
    website?: Maybe<Scalars['String']>;
    gender?: Maybe<Scalars['String']>;
    birthdate?: Maybe<Scalars['String']>;
    zoneinfo?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    formatted?: Maybe<Scalars['String']>;
    streetAddress?: Maybe<Scalars['String']>;
    locality?: Maybe<Scalars['String']>;
    region?: Maybe<Scalars['String']>;
    postalCode?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    udf?: Maybe<Array<UserDdfInput>>;
};
export declare type UserDdfInput = {
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type RegisterByEmailInput = {
    email: Scalars['String'];
    password: Scalars['String'];
    profile?: Maybe<RegisterProfile>;
    forceLogin?: Maybe<Scalars['Boolean']>;
    generateToken?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }> */
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline. */
    context?: Maybe<Scalars['String']>;
};
export declare type RegisterByPhoneCodeInput = {
    phone: Scalars['String'];
    code: Scalars['String'];
    password?: Maybe<Scalars['String']>;
    profile?: Maybe<RegisterProfile>;
    forceLogin?: Maybe<Scalars['Boolean']>;
    generateToken?: Maybe<Scalars['Boolean']>;
    clientIp?: Maybe<Scalars['String']>;
    /** Set user-defined field. It has to match form: Array<{ key: string; value: string }> */
    params?: Maybe<Scalars['String']>;
    /** Request context. It will be parsed into the pipeline. */
    context?: Maybe<Scalars['String']>;
};
export declare type SetUdfValueBatchInput = {
    targetId: Scalars['String'];
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type UserDefinedDataInput = {
    key: Scalars['String'];
    value?: Maybe<Scalars['String']>;
};
export declare type RefreshToken = {
    token?: Maybe<Scalars['String']>;
    iat?: Maybe<Scalars['Int']>;
    exp?: Maybe<Scalars['Int']>;
};
export declare type CreateUserInput = {
    /** Username. Unique in user pool */
    username?: Maybe<Scalars['String']>;
    /** Email. Not case sensitive. unique in user pool. */
    email?: Maybe<Scalars['String']>;
    /** Whether the email is verified */
    emailVerified?: Maybe<Scalars['Boolean']>;
    /** Phone number, unique in user pool. */
    phone?: Maybe<Scalars['String']>;
    /** Whether phone number is verified. */
    phoneVerified?: Maybe<Scalars['Boolean']>;
    unionid?: Maybe<Scalars['String']>;
    openid?: Maybe<Scalars['String']>;
    /** Nickname. This field doesn't have to be unique. */
    nickname?: Maybe<Scalars['String']>;
    /** Avatar link. The default value is https://usercontents.approw.com/approw-avatar.png */
    photo?: Maybe<Scalars['String']>;
    password?: Maybe<Scalars['String']>;
    /**  */
    registerSource?: Maybe<Array<Scalars['String']>>;
    browser?: Maybe<Scalars['String']>;
    /** The original user info returned by third-party social IDP. For non-social register users this field is empty.  */
    oauth?: Maybe<Scalars['String']>;
    /** User login counter. You can set this value when migrating users from original system to Approw. */
    loginsCount?: Maybe<Scalars['Int']>;
    lastLogin?: Maybe<Scalars['String']>;
    company?: Maybe<Scalars['String']>;
    lastIP?: Maybe<Scalars['String']>;
    /** User register time. You can set this value when migrating users from original system to Approw. */
    signedUp?: Maybe<Scalars['String']>;
    blocked?: Maybe<Scalars['Boolean']>;
    isDeleted?: Maybe<Scalars['Boolean']>;
    device?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    middleName?: Maybe<Scalars['String']>;
    profile?: Maybe<Scalars['String']>;
    preferredUsername?: Maybe<Scalars['String']>;
    website?: Maybe<Scalars['String']>;
    gender?: Maybe<Scalars['String']>;
    birthdate?: Maybe<Scalars['String']>;
    zoneinfo?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    formatted?: Maybe<Scalars['String']>;
    streetAddress?: Maybe<Scalars['String']>;
    locality?: Maybe<Scalars['String']>;
    region?: Maybe<Scalars['String']>;
    postalCode?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    externalId?: Maybe<Scalars['String']>;
};
export declare type UpdateUserInput = {
    /** Email. Changing user email directly requires admin privileges. For normal users please use **updateEmail** API. */
    email?: Maybe<Scalars['String']>;
    unionid?: Maybe<Scalars['String']>;
    openid?: Maybe<Scalars['String']>;
    /** Whether the email is verified. Changing **emailVerified** requires admin privileges. */
    emailVerified?: Maybe<Scalars['Boolean']>;
    /** Phone number. Directly changing phone number requires admin privileges. For normal users, please use **updatePhone** API. */
    phone?: Maybe<Scalars['String']>;
    /** Whether the phone number is verified. Changing **phoneVerified** directly requires admin privileges. */
    phoneVerified?: Maybe<Scalars['Boolean']>;
    /** username, unique in user pool. */
    username?: Maybe<Scalars['String']>;
    /** Nickname, not unique */
    nickname?: Maybe<Scalars['String']>;
    /** Password. Changing password directly requires admin privileges. For normal users, please use **updatePassword** API. */
    password?: Maybe<Scalars['String']>;
    /** Avatar link, the default value is: https://usercontents.approw.com/approw-avatar.png */
    photo?: Maybe<Scalars['String']>;
    /**  */
    company?: Maybe<Scalars['String']>;
    browser?: Maybe<Scalars['String']>;
    device?: Maybe<Scalars['String']>;
    oauth?: Maybe<Scalars['String']>;
    tokenExpiredAt?: Maybe<Scalars['String']>;
    /** User login counter. You can set this value when migrating your users from original system to Approw. */
    loginsCount?: Maybe<Scalars['Int']>;
    lastLogin?: Maybe<Scalars['String']>;
    lastIP?: Maybe<Scalars['String']>;
    /** User register time. You can set this value when migrating your users from original system to Approw. */
    blocked?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    middleName?: Maybe<Scalars['String']>;
    profile?: Maybe<Scalars['String']>;
    preferredUsername?: Maybe<Scalars['String']>;
    website?: Maybe<Scalars['String']>;
    gender?: Maybe<Scalars['String']>;
    birthdate?: Maybe<Scalars['String']>;
    zoneinfo?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    formatted?: Maybe<Scalars['String']>;
    streetAddress?: Maybe<Scalars['String']>;
    locality?: Maybe<Scalars['String']>;
    region?: Maybe<Scalars['String']>;
    postalCode?: Maybe<Scalars['String']>;
    city?: Maybe<Scalars['String']>;
    province?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    externalId?: Maybe<Scalars['String']>;
};
export declare type UpdateUserpoolInput = {
    name?: Maybe<Scalars['String']>;
    logo?: Maybe<Scalars['String']>;
    domain?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    userpoolTypes?: Maybe<Array<Scalars['String']>>;
    emailVerifiedDefault?: Maybe<Scalars['Boolean']>;
    sendWelcomeEmail?: Maybe<Scalars['Boolean']>;
    registerDisabled?: Maybe<Scalars['Boolean']>;
    appSsoEnabled?: Maybe<Scalars['Boolean']>;
    allowedOrigins?: Maybe<Scalars['String']>;
    tokenExpiresAfter?: Maybe<Scalars['Int']>;
    frequentRegisterCheck?: Maybe<FrequentRegisterCheckConfigInput>;
    loginFailCheck?: Maybe<LoginFailCheckConfigInput>;
    changePhoneStrategy?: Maybe<ChangePhoneStrategyInput>;
    changeEmailStrategy?: Maybe<ChangeEmailStrategyInput>;
    qrcodeLoginStrategy?: Maybe<QrcodeLoginStrategyInput>;
    app2WxappLoginStrategy?: Maybe<App2WxappLoginStrategyInput>;
    whitelist?: Maybe<RegisterWhiteListConfigInput>;
    /** custom SMS provider config */
    customSMSProvider?: Maybe<CustomSmsProviderInput>;
    /** Whether requires email verification when logging in */
    loginRequireEmailVerified?: Maybe<Scalars['Boolean']>;
    verifyCodeLength?: Maybe<Scalars['Int']>;
};
export declare type FrequentRegisterCheckConfigInput = {
    timeInterval?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    enabled?: Maybe<Scalars['Boolean']>;
};
export declare type LoginFailCheckConfigInput = {
    timeInterval?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    enabled?: Maybe<Scalars['Boolean']>;
};
export declare type ChangePhoneStrategyInput = {
    verifyOldPhone?: Maybe<Scalars['Boolean']>;
};
export declare type ChangeEmailStrategyInput = {
    verifyOldEmail?: Maybe<Scalars['Boolean']>;
};
export declare type QrcodeLoginStrategyInput = {
    qrcodeExpiresAfter?: Maybe<Scalars['Int']>;
    returnFullUserInfo?: Maybe<Scalars['Boolean']>;
    allowExchangeUserInfoFromBrowser?: Maybe<Scalars['Boolean']>;
    ticketExpiresAfter?: Maybe<Scalars['Int']>;
};
export declare type App2WxappLoginStrategyInput = {
    ticketExpriresAfter?: Maybe<Scalars['Int']>;
    ticketExchangeUserInfoNeedSecret?: Maybe<Scalars['Boolean']>;
};
export declare type RegisterWhiteListConfigInput = {
    phoneEnabled?: Maybe<Scalars['Boolean']>;
    emailEnabled?: Maybe<Scalars['Boolean']>;
    usernameEnabled?: Maybe<Scalars['Boolean']>;
};
export declare type CustomSmsProviderInput = {
    enabled?: Maybe<Scalars['Boolean']>;
    provider?: Maybe<Scalars['String']>;
    config?: Maybe<Scalars['String']>;
};
export declare type RefreshAccessTokenRes = {
    accessToken?: Maybe<Scalars['String']>;
    exp?: Maybe<Scalars['Int']>;
    iat?: Maybe<Scalars['Int']>;
};
/** batch delete returned values */
export declare type BatchOperationResult = {
    /** successfully deleted count */
    succeedCount: Scalars['Int'];
    /** delete failed count */
    failedCount: Scalars['Int'];
    message?: Maybe<Scalars['String']>;
    errors?: Maybe<Array<Scalars['String']>>;
};
export declare type KeyValuePair = {
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type SocialConnectionFieldInput = {
    key?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
    placeholder?: Maybe<Scalars['String']>;
    children?: Maybe<Array<Maybe<SocialConnectionFieldInput>>>;
};
export declare type CreateSocialConnectionInput = {
    provider: Scalars['String'];
    name: Scalars['String'];
    logo: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    fields?: Maybe<Array<SocialConnectionFieldInput>>;
};
export declare type AddMemberVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
    includeChildrenNodes?: Maybe<Scalars['Boolean']>;
    nodeId?: Maybe<Scalars['String']>;
    orgId?: Maybe<Scalars['String']>;
    nodeCode?: Maybe<Scalars['String']>;
    userIds: Array<Scalars['String']>;
    isLeader?: Maybe<Scalars['Boolean']>;
}>;
export declare type AddMemberResponse = {
    addMember: {
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
        users: {
            totalCount: number;
            list: Array<{
                id: string;
                arn: string;
                userPoolId: string;
                username?: Maybe<string>;
                status?: Maybe<UserStatus>;
                email?: Maybe<string>;
                emailVerified?: Maybe<boolean>;
                phone?: Maybe<string>;
                phoneVerified?: Maybe<boolean>;
                unionid?: Maybe<string>;
                openid?: Maybe<string>;
                nickname?: Maybe<string>;
                registerSource?: Maybe<Array<string>>;
                photo?: Maybe<string>;
                password?: Maybe<string>;
                oauth?: Maybe<string>;
                token?: Maybe<string>;
                tokenExpiredAt?: Maybe<string>;
                loginsCount?: Maybe<number>;
                lastLogin?: Maybe<string>;
                lastIP?: Maybe<string>;
                signedUp?: Maybe<string>;
                blocked?: Maybe<boolean>;
                isDeleted?: Maybe<boolean>;
                device?: Maybe<string>;
                browser?: Maybe<string>;
                company?: Maybe<string>;
                name?: Maybe<string>;
                givenName?: Maybe<string>;
                familyName?: Maybe<string>;
                middleName?: Maybe<string>;
                profile?: Maybe<string>;
                preferredUsername?: Maybe<string>;
                website?: Maybe<string>;
                gender?: Maybe<string>;
                birthdate?: Maybe<string>;
                zoneinfo?: Maybe<string>;
                locale?: Maybe<string>;
                address?: Maybe<string>;
                formatted?: Maybe<string>;
                streetAddress?: Maybe<string>;
                locality?: Maybe<string>;
                region?: Maybe<string>;
                postalCode?: Maybe<string>;
                city?: Maybe<string>;
                province?: Maybe<string>;
                country?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                externalId?: Maybe<string>;
            }>;
        };
    };
};
export declare type AddNodeVariables = Exact<{
    orgId: Scalars['String'];
    parentNodeId?: Maybe<Scalars['String']>;
    name: Scalars['String'];
    nameI18n?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    descriptionI18n?: Maybe<Scalars['String']>;
    order?: Maybe<Scalars['Int']>;
    code?: Maybe<Scalars['String']>;
}>;
export declare type AddNodeResponse = {
    addNode: {
        id: string;
        rootNode: {
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        };
        nodes: Array<{
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        }>;
    };
};
export declare type AddNodeV2Variables = Exact<{
    orgId: Scalars['String'];
    parentNodeId?: Maybe<Scalars['String']>;
    name: Scalars['String'];
    nameI18n?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    descriptionI18n?: Maybe<Scalars['String']>;
    order?: Maybe<Scalars['Int']>;
    code?: Maybe<Scalars['String']>;
}>;
export declare type AddNodeV2Response = {
    addNodeV2: {
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
    };
};
export declare type AddPolicyAssignmentsVariables = Exact<{
    policies: Array<Scalars['String']>;
    targetType: PolicyAssignmentTargetType;
    targetIdentifiers?: Maybe<Array<Scalars['String']>>;
    inheritByChildren?: Maybe<Scalars['Boolean']>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type AddPolicyAssignmentsResponse = {
    addPolicyAssignments: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type AddUserToGroupVariables = Exact<{
    userIds: Array<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
}>;
export declare type AddUserToGroupResponse = {
    addUserToGroup: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type AddWhitelistVariables = Exact<{
    type: WhitelistType;
    list: Array<Scalars['String']>;
}>;
export declare type AddWhitelistResponse = {
    addWhitelist: Array<Maybe<{
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        value: string;
    }>>;
};
export declare type AllowVariables = Exact<{
    resource: Scalars['String'];
    action: Scalars['String'];
    userId?: Maybe<Scalars['String']>;
    userIds?: Maybe<Array<Scalars['String']>>;
    roleCode?: Maybe<Scalars['String']>;
    roleCodes?: Maybe<Array<Scalars['String']>>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type AllowResponse = {
    allow: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type AssignRoleVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    roleCode?: Maybe<Scalars['String']>;
    roleCodes?: Maybe<Array<Maybe<Scalars['String']>>>;
    userIds?: Maybe<Array<Scalars['String']>>;
    groupCodes?: Maybe<Array<Scalars['String']>>;
    nodeCodes?: Maybe<Array<Scalars['String']>>;
}>;
export declare type AssignRoleResponse = {
    assignRole?: Maybe<{
        message?: Maybe<string>;
        code?: Maybe<number>;
    }>;
};
export declare type AuthorizeResourceVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    resource?: Maybe<Scalars['String']>;
    resourceType?: Maybe<ResourceType>;
    opts?: Maybe<Array<Maybe<AuthorizeResourceOpt>>>;
}>;
export declare type AuthorizeResourceResponse = {
    authorizeResource: {
        code?: Maybe<number>;
        message?: Maybe<string>;
    };
};
export declare type BindEmailVariables = Exact<{
    email: Scalars['String'];
    emailCode: Scalars['String'];
}>;
export declare type BindEmailResponse = {
    bindEmail: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type BindPhoneVariables = Exact<{
    phone: Scalars['String'];
    phoneCode: Scalars['String'];
}>;
export declare type BindPhoneResponse = {
    bindPhone: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type ChangeMfaVariables = Exact<{
    enable?: Maybe<Scalars['Boolean']>;
    id?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    userPoolId?: Maybe<Scalars['String']>;
    refresh?: Maybe<Scalars['Boolean']>;
}>;
export declare type ChangeMfaResponse = {
    changeMfa?: Maybe<{
        id: string;
        userId: string;
        userPoolId: string;
        enable: boolean;
        secret?: Maybe<string>;
    }>;
};
export declare type ConfigEmailTemplateVariables = Exact<{
    input: ConfigEmailTemplateInput;
}>;
export declare type ConfigEmailTemplateResponse = {
    configEmailTemplate: {
        type: EmailTemplateType;
        name: string;
        subject: string;
        sender: string;
        content: string;
        redirectTo?: Maybe<string>;
        hasURL?: Maybe<boolean>;
        expiresIn?: Maybe<number>;
        enabled?: Maybe<boolean>;
        isSystem?: Maybe<boolean>;
    };
};
export declare type CreateFunctionVariables = Exact<{
    input: CreateFunctionInput;
}>;
export declare type CreateFunctionResponse = {
    createFunction?: Maybe<{
        id: string;
        name: string;
        sourceCode: string;
        description?: Maybe<string>;
        url?: Maybe<string>;
    }>;
};
export declare type CreateGroupVariables = Exact<{
    code: Scalars['String'];
    name: Scalars['String'];
    description?: Maybe<Scalars['String']>;
}>;
export declare type CreateGroupResponse = {
    createGroup: {
        code: string;
        name: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type CreateOrgVariables = Exact<{
    name: Scalars['String'];
    code?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
}>;
export declare type CreateOrgResponse = {
    createOrg: {
        id: string;
        rootNode: {
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        };
        nodes: Array<{
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        }>;
    };
};
export declare type CreatePolicyVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    statements: Array<PolicyStatementInput>;
}>;
export declare type CreatePolicyResponse = {
    createPolicy: {
        namespace: string;
        code: string;
        isDefault: boolean;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        assignmentsCount: number;
        statements: Array<{
            resource: string;
            actions: Array<string>;
            effect?: Maybe<PolicyEffect>;
            condition?: Maybe<Array<{
                param: string;
                operator: string;
                value: any;
            }>>;
        }>;
    };
};
export declare type CreateRoleVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    parent?: Maybe<Scalars['String']>;
}>;
export declare type CreateRoleResponse = {
    createRole: {
        namespace: string;
        code: string;
        arn: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        parent?: Maybe<{
            namespace: string;
            code: string;
            arn: string;
            description?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
        }>;
    };
};
export declare type CreateSocialConnectionInstanceVariables = Exact<{
    input: CreateSocialConnectionInstanceInput;
}>;
export declare type CreateSocialConnectionInstanceResponse = {
    createSocialConnectionInstance: {
        provider: string;
        enabled: boolean;
        fields?: Maybe<Array<Maybe<{
            key: string;
            value: string;
        }>>>;
    };
};
export declare type CreateUserVariables = Exact<{
    userInfo: CreateUserInput;
    keepPassword?: Maybe<Scalars['Boolean']>;
}>;
export declare type CreateUserResponse = {
    createUser: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    };
};
export declare type CreateUserpoolVariables = Exact<{
    name: Scalars['String'];
    domain: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    logo?: Maybe<Scalars['String']>;
    userpoolTypes?: Maybe<Array<Scalars['String']>>;
}>;
export declare type CreateUserpoolResponse = {
    createUserpool: {
        id: string;
        name: string;
        domain: string;
        description?: Maybe<string>;
        secret: string;
        jwtSecret: string;
        logo: string;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        emailVerifiedDefault: boolean;
        sendWelcomeEmail: boolean;
        registerDisabled: boolean;
        appSsoEnabled: boolean;
        showWxQRCodeWhenRegisterDisabled?: Maybe<boolean>;
        allowedOrigins?: Maybe<string>;
        tokenExpiresAfter?: Maybe<number>;
        isDeleted?: Maybe<boolean>;
        packageType?: Maybe<number>;
        userpoolTypes?: Maybe<Array<{
            code?: Maybe<string>;
            name?: Maybe<string>;
            description?: Maybe<string>;
            image?: Maybe<string>;
            sdks?: Maybe<Array<Maybe<string>>>;
        }>>;
        frequentRegisterCheck?: Maybe<{
            timeInterval?: Maybe<number>;
            limit?: Maybe<number>;
            enabled?: Maybe<boolean>;
        }>;
        loginFailCheck?: Maybe<{
            timeInterval?: Maybe<number>;
            limit?: Maybe<number>;
            enabled?: Maybe<boolean>;
        }>;
        changePhoneStrategy?: Maybe<{
            verifyOldPhone?: Maybe<boolean>;
        }>;
        changeEmailStrategy?: Maybe<{
            verifyOldEmail?: Maybe<boolean>;
        }>;
        qrcodeLoginStrategy?: Maybe<{
            qrcodeExpiresAfter?: Maybe<number>;
            returnFullUserInfo?: Maybe<boolean>;
            allowExchangeUserInfoFromBrowser?: Maybe<boolean>;
            ticketExpiresAfter?: Maybe<number>;
        }>;
        app2WxappLoginStrategy?: Maybe<{
            ticketExpriresAfter?: Maybe<number>;
            ticketExchangeUserInfoNeedSecret?: Maybe<boolean>;
        }>;
        whitelist?: Maybe<{
            phoneEnabled?: Maybe<boolean>;
            emailEnabled?: Maybe<boolean>;
            usernameEnabled?: Maybe<boolean>;
        }>;
        customSMSProvider?: Maybe<{
            enabled?: Maybe<boolean>;
            provider?: Maybe<string>;
        }>;
    };
};
export declare type DeleteFunctionVariables = Exact<{
    id: Scalars['String'];
}>;
export declare type DeleteFunctionResponse = {
    deleteFunction: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteGroupsVariables = Exact<{
    codeList: Array<Scalars['String']>;
}>;
export declare type DeleteGroupsResponse = {
    deleteGroups: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteNodeVariables = Exact<{
    orgId: Scalars['String'];
    nodeId: Scalars['String'];
}>;
export declare type DeleteNodeResponse = {
    deleteNode: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteOrgVariables = Exact<{
    id: Scalars['String'];
}>;
export declare type DeleteOrgResponse = {
    deleteOrg: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeletePoliciesVariables = Exact<{
    codeList: Array<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type DeletePoliciesResponse = {
    deletePolicies: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeletePolicyVariables = Exact<{
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type DeletePolicyResponse = {
    deletePolicy: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteRoleVariables = Exact<{
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type DeleteRoleResponse = {
    deleteRole: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteRolesVariables = Exact<{
    codeList: Array<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type DeleteRolesResponse = {
    deleteRoles: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteUserVariables = Exact<{
    id: Scalars['String'];
}>;
export declare type DeleteUserResponse = {
    deleteUser?: Maybe<{
        message?: Maybe<string>;
        code?: Maybe<number>;
    }>;
};
export declare type DeleteUserpoolVariables = Exact<{
    [key: string]: never;
}>;
export declare type DeleteUserpoolResponse = {
    deleteUserpool: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type DeleteUsersVariables = Exact<{
    ids: Array<Scalars['String']>;
}>;
export declare type DeleteUsersResponse = {
    deleteUsers?: Maybe<{
        message?: Maybe<string>;
        code?: Maybe<number>;
    }>;
};
export declare type DisableEmailTemplateVariables = Exact<{
    type: EmailTemplateType;
}>;
export declare type DisableEmailTemplateResponse = {
    disableEmailTemplate: {
        type: EmailTemplateType;
        name: string;
        subject: string;
        sender: string;
        content: string;
        redirectTo?: Maybe<string>;
        hasURL?: Maybe<boolean>;
        expiresIn?: Maybe<number>;
        enabled?: Maybe<boolean>;
        isSystem?: Maybe<boolean>;
    };
};
export declare type DisableSocialConnectionInstanceVariables = Exact<{
    provider: Scalars['String'];
}>;
export declare type DisableSocialConnectionInstanceResponse = {
    disableSocialConnectionInstance: {
        provider: string;
        enabled: boolean;
        fields?: Maybe<Array<Maybe<{
            key: string;
            value: string;
        }>>>;
    };
};
export declare type DisbalePolicyAssignmentVariables = Exact<{
    policy: Scalars['String'];
    targetType: PolicyAssignmentTargetType;
    targetIdentifier: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type DisbalePolicyAssignmentResponse = {
    disbalePolicyAssignment: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type EnableEmailTemplateVariables = Exact<{
    type: EmailTemplateType;
}>;
export declare type EnableEmailTemplateResponse = {
    enableEmailTemplate: {
        type: EmailTemplateType;
        name: string;
        subject: string;
        sender: string;
        content: string;
        redirectTo?: Maybe<string>;
        hasURL?: Maybe<boolean>;
        expiresIn?: Maybe<number>;
        enabled?: Maybe<boolean>;
        isSystem?: Maybe<boolean>;
    };
};
export declare type EnablePolicyAssignmentVariables = Exact<{
    policy: Scalars['String'];
    targetType: PolicyAssignmentTargetType;
    targetIdentifier: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type EnablePolicyAssignmentResponse = {
    enablePolicyAssignment: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type EnableSocialConnectionInstanceVariables = Exact<{
    provider: Scalars['String'];
}>;
export declare type EnableSocialConnectionInstanceResponse = {
    enableSocialConnectionInstance: {
        provider: string;
        enabled: boolean;
        fields?: Maybe<Array<Maybe<{
            key: string;
            value: string;
        }>>>;
    };
};
export declare type LoginByEmailVariables = Exact<{
    input: LoginByEmailInput;
}>;
export declare type LoginByEmailResponse = {
    loginByEmail?: Maybe<{
        id: string;
        arn: string;
        status?: Maybe<UserStatus>;
        userPoolId: string;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type LoginByPhoneCodeVariables = Exact<{
    input: LoginByPhoneCodeInput;
}>;
export declare type LoginByPhoneCodeResponse = {
    loginByPhoneCode?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type LoginByPhonePasswordVariables = Exact<{
    input: LoginByPhonePasswordInput;
}>;
export declare type LoginByPhonePasswordResponse = {
    loginByPhonePassword?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type LoginBySubAccountVariables = Exact<{
    account: Scalars['String'];
    password: Scalars['String'];
    captchaCode?: Maybe<Scalars['String']>;
    clientIp?: Maybe<Scalars['String']>;
}>;
export declare type LoginBySubAccountResponse = {
    loginBySubAccount: {
        id: string;
        arn: string;
        status?: Maybe<UserStatus>;
        userPoolId: string;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    };
};
export declare type LoginByUsernameVariables = Exact<{
    input: LoginByUsernameInput;
}>;
export declare type LoginByUsernameResponse = {
    loginByUsername?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type MoveNodeVariables = Exact<{
    orgId: Scalars['String'];
    nodeId: Scalars['String'];
    targetParentId: Scalars['String'];
}>;
export declare type MoveNodeResponse = {
    moveNode: {
        id: string;
        rootNode: {
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        };
        nodes: Array<{
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        }>;
    };
};
export declare type RefreshAccessTokenVariables = Exact<{
    accessToken?: Maybe<Scalars['String']>;
}>;
export declare type RefreshAccessTokenResponse = {
    refreshAccessToken: {
        accessToken?: Maybe<string>;
        exp?: Maybe<number>;
        iat?: Maybe<number>;
    };
};
export declare type RefreshTokenVariables = Exact<{
    id?: Maybe<Scalars['String']>;
}>;
export declare type RefreshTokenResponse = {
    refreshToken?: Maybe<{
        token?: Maybe<string>;
        iat?: Maybe<number>;
        exp?: Maybe<number>;
    }>;
};
export declare type RefreshUserpoolSecretVariables = Exact<{
    [key: string]: never;
}>;
export declare type RefreshUserpoolSecretResponse = {
    refreshUserpoolSecret: string;
};
export declare type RegisterByEmailVariables = Exact<{
    input: RegisterByEmailInput;
}>;
export declare type RegisterByEmailResponse = {
    registerByEmail?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type RegisterByPhoneCodeVariables = Exact<{
    input: RegisterByPhoneCodeInput;
}>;
export declare type RegisterByPhoneCodeResponse = {
    registerByPhoneCode?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type RegisterByUsernameVariables = Exact<{
    input: RegisterByUsernameInput;
}>;
export declare type RegisterByUsernameResponse = {
    registerByUsername?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type RemoveMemberVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
    includeChildrenNodes?: Maybe<Scalars['Boolean']>;
    nodeId?: Maybe<Scalars['String']>;
    orgId?: Maybe<Scalars['String']>;
    nodeCode?: Maybe<Scalars['String']>;
    userIds: Array<Scalars['String']>;
}>;
export declare type RemoveMemberResponse = {
    removeMember: {
        id: string;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
        users: {
            totalCount: number;
            list: Array<{
                id: string;
                arn: string;
                userPoolId: string;
                status?: Maybe<UserStatus>;
                username?: Maybe<string>;
                email?: Maybe<string>;
                emailVerified?: Maybe<boolean>;
                phone?: Maybe<string>;
                phoneVerified?: Maybe<boolean>;
                unionid?: Maybe<string>;
                openid?: Maybe<string>;
                nickname?: Maybe<string>;
                registerSource?: Maybe<Array<string>>;
                photo?: Maybe<string>;
                password?: Maybe<string>;
                oauth?: Maybe<string>;
                token?: Maybe<string>;
                tokenExpiredAt?: Maybe<string>;
                loginsCount?: Maybe<number>;
                lastLogin?: Maybe<string>;
                lastIP?: Maybe<string>;
                signedUp?: Maybe<string>;
                blocked?: Maybe<boolean>;
                isDeleted?: Maybe<boolean>;
                device?: Maybe<string>;
                browser?: Maybe<string>;
                company?: Maybe<string>;
                name?: Maybe<string>;
                givenName?: Maybe<string>;
                familyName?: Maybe<string>;
                middleName?: Maybe<string>;
                profile?: Maybe<string>;
                preferredUsername?: Maybe<string>;
                website?: Maybe<string>;
                gender?: Maybe<string>;
                birthdate?: Maybe<string>;
                zoneinfo?: Maybe<string>;
                locale?: Maybe<string>;
                address?: Maybe<string>;
                formatted?: Maybe<string>;
                streetAddress?: Maybe<string>;
                locality?: Maybe<string>;
                region?: Maybe<string>;
                postalCode?: Maybe<string>;
                city?: Maybe<string>;
                province?: Maybe<string>;
                country?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
            }>;
        };
    };
};
export declare type RemovePolicyAssignmentsVariables = Exact<{
    policies: Array<Scalars['String']>;
    targetType: PolicyAssignmentTargetType;
    targetIdentifiers?: Maybe<Array<Scalars['String']>>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type RemovePolicyAssignmentsResponse = {
    removePolicyAssignments: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type RemoveUdfVariables = Exact<{
    targetType: UdfTargetType;
    key: Scalars['String'];
}>;
export declare type RemoveUdfResponse = {
    removeUdf?: Maybe<{
        message?: Maybe<string>;
        code?: Maybe<number>;
    }>;
};
export declare type RemoveUdvVariables = Exact<{
    targetType: UdfTargetType;
    targetId: Scalars['String'];
    key: Scalars['String'];
}>;
export declare type RemoveUdvResponse = {
    removeUdv?: Maybe<Array<{
        key: string;
        dataType: UdfDataType;
        value: string;
        label?: Maybe<string>;
    }>>;
};
export declare type RemoveUserFromGroupVariables = Exact<{
    userIds: Array<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
}>;
export declare type RemoveUserFromGroupResponse = {
    removeUserFromGroup: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type RemoveWhitelistVariables = Exact<{
    type: WhitelistType;
    list: Array<Scalars['String']>;
}>;
export declare type RemoveWhitelistResponse = {
    removeWhitelist: Array<Maybe<{
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        value: string;
    }>>;
};
export declare type ResetPasswordVariables = Exact<{
    phone?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    newPassword: Scalars['String'];
}>;
export declare type ResetPasswordResponse = {
    resetPassword?: Maybe<{
        message?: Maybe<string>;
        code?: Maybe<number>;
    }>;
};
export declare type RevokeRoleVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    roleCode?: Maybe<Scalars['String']>;
    roleCodes?: Maybe<Array<Maybe<Scalars['String']>>>;
    userIds?: Maybe<Array<Scalars['String']>>;
    groupCodes?: Maybe<Array<Scalars['String']>>;
    nodeCodes?: Maybe<Array<Scalars['String']>>;
}>;
export declare type RevokeRoleResponse = {
    revokeRole?: Maybe<{
        message?: Maybe<string>;
        code?: Maybe<number>;
    }>;
};
export declare type SendEmailVariables = Exact<{
    email: Scalars['String'];
    scene: EmailScene;
}>;
export declare type SendEmailResponse = {
    sendEmail: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type SetMainDepartmentVariables = Exact<{
    userId: Scalars['String'];
    departmentId?: Maybe<Scalars['String']>;
}>;
export declare type SetMainDepartmentResponse = {
    setMainDepartment: {
        message?: Maybe<string>;
        code?: Maybe<number>;
    };
};
export declare type SetUdfVariables = Exact<{
    targetType: UdfTargetType;
    key: Scalars['String'];
    dataType: UdfDataType;
    label: Scalars['String'];
    options?: Maybe<Scalars['String']>;
}>;
export declare type SetUdfResponse = {
    setUdf: {
        targetType: UdfTargetType;
        dataType: UdfDataType;
        key: string;
        label?: Maybe<string>;
        options?: Maybe<string>;
    };
};
export declare type SetUdfValueBatchVariables = Exact<{
    targetType: UdfTargetType;
    input: Array<SetUdfValueBatchInput>;
}>;
export declare type SetUdfValueBatchResponse = {
    setUdfValueBatch?: Maybe<{
        code?: Maybe<number>;
        message?: Maybe<string>;
    }>;
};
export declare type SetUdvVariables = Exact<{
    targetType: UdfTargetType;
    targetId: Scalars['String'];
    key: Scalars['String'];
    value: Scalars['String'];
}>;
export declare type SetUdvResponse = {
    setUdv?: Maybe<Array<{
        key: string;
        dataType: UdfDataType;
        value: string;
        label?: Maybe<string>;
    }>>;
};
export declare type SetUdvBatchVariables = Exact<{
    targetType: UdfTargetType;
    targetId: Scalars['String'];
    udvList?: Maybe<Array<UserDefinedDataInput>>;
}>;
export declare type SetUdvBatchResponse = {
    setUdvBatch?: Maybe<Array<{
        key: string;
        dataType: UdfDataType;
        value: string;
        label?: Maybe<string>;
    }>>;
};
export declare type UnbindEmailVariables = Exact<{
    [key: string]: never;
}>;
export declare type UnbindEmailResponse = {
    unbindEmail: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type UnbindPhoneVariables = Exact<{
    [key: string]: never;
}>;
export declare type UnbindPhoneResponse = {
    unbindPhone: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type UpdateEmailVariables = Exact<{
    email: Scalars['String'];
    emailCode: Scalars['String'];
    oldEmail?: Maybe<Scalars['String']>;
    oldEmailCode?: Maybe<Scalars['String']>;
}>;
export declare type UpdateEmailResponse = {
    updateEmail: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type UpdateFunctionVariables = Exact<{
    input: UpdateFunctionInput;
}>;
export declare type UpdateFunctionResponse = {
    updateFunction: {
        id: string;
        name: string;
        sourceCode: string;
        description?: Maybe<string>;
        url?: Maybe<string>;
    };
};
export declare type UpdateGroupVariables = Exact<{
    code: Scalars['String'];
    name?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    newCode?: Maybe<Scalars['String']>;
}>;
export declare type UpdateGroupResponse = {
    updateGroup: {
        code: string;
        name: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type UpdateNodeVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
    includeChildrenNodes?: Maybe<Scalars['Boolean']>;
    id: Scalars['String'];
    name?: Maybe<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
}>;
export declare type UpdateNodeResponse = {
    updateNode: {
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
        users: {
            totalCount: number;
        };
    };
};
export declare type UpdatePasswordVariables = Exact<{
    newPassword: Scalars['String'];
    oldPassword?: Maybe<Scalars['String']>;
}>;
export declare type UpdatePasswordResponse = {
    updatePassword: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type UpdatePhoneVariables = Exact<{
    phone: Scalars['String'];
    phoneCode: Scalars['String'];
    oldPhone?: Maybe<Scalars['String']>;
    oldPhoneCode?: Maybe<Scalars['String']>;
}>;
export declare type UpdatePhoneResponse = {
    updatePhone: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    };
};
export declare type UpdatePolicyVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    statements?: Maybe<Array<PolicyStatementInput>>;
    newCode?: Maybe<Scalars['String']>;
}>;
export declare type UpdatePolicyResponse = {
    updatePolicy: {
        namespace: string;
        code: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        statements: Array<{
            resource: string;
            actions: Array<string>;
            effect?: Maybe<PolicyEffect>;
            condition?: Maybe<Array<{
                param: string;
                operator: string;
                value: any;
            }>>;
        }>;
    };
};
export declare type UpdateRoleVariables = Exact<{
    code: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    newCode?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type UpdateRoleResponse = {
    updateRole: {
        namespace: string;
        code: string;
        arn: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        parent?: Maybe<{
            namespace: string;
            code: string;
            arn: string;
            description?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
        }>;
    };
};
export declare type UpdateUserVariables = Exact<{
    id?: Maybe<Scalars['String']>;
    input: UpdateUserInput;
}>;
export declare type UpdateUserResponse = {
    updateUser: {
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    };
};
export declare type UpdateUserpoolVariables = Exact<{
    input: UpdateUserpoolInput;
}>;
export declare type UpdateUserpoolResponse = {
    updateUserpool: {
        id: string;
        name: string;
        domain: string;
        description?: Maybe<string>;
        secret: string;
        jwtSecret: string;
        logo: string;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        emailVerifiedDefault: boolean;
        sendWelcomeEmail: boolean;
        registerDisabled: boolean;
        appSsoEnabled: boolean;
        showWxQRCodeWhenRegisterDisabled?: Maybe<boolean>;
        allowedOrigins?: Maybe<string>;
        tokenExpiresAfter?: Maybe<number>;
        isDeleted?: Maybe<boolean>;
        packageType?: Maybe<number>;
        useCustomUserStore?: Maybe<boolean>;
        loginRequireEmailVerified?: Maybe<boolean>;
        verifyCodeLength?: Maybe<number>;
        userpoolTypes?: Maybe<Array<{
            code?: Maybe<string>;
            name?: Maybe<string>;
            description?: Maybe<string>;
            image?: Maybe<string>;
            sdks?: Maybe<Array<Maybe<string>>>;
        }>>;
        frequentRegisterCheck?: Maybe<{
            timeInterval?: Maybe<number>;
            limit?: Maybe<number>;
            enabled?: Maybe<boolean>;
        }>;
        loginFailCheck?: Maybe<{
            timeInterval?: Maybe<number>;
            limit?: Maybe<number>;
            enabled?: Maybe<boolean>;
        }>;
        changePhoneStrategy?: Maybe<{
            verifyOldPhone?: Maybe<boolean>;
        }>;
        changeEmailStrategy?: Maybe<{
            verifyOldEmail?: Maybe<boolean>;
        }>;
        qrcodeLoginStrategy?: Maybe<{
            qrcodeExpiresAfter?: Maybe<number>;
            returnFullUserInfo?: Maybe<boolean>;
            allowExchangeUserInfoFromBrowser?: Maybe<boolean>;
            ticketExpiresAfter?: Maybe<number>;
        }>;
        app2WxappLoginStrategy?: Maybe<{
            ticketExpriresAfter?: Maybe<number>;
            ticketExchangeUserInfoNeedSecret?: Maybe<boolean>;
        }>;
        whitelist?: Maybe<{
            phoneEnabled?: Maybe<boolean>;
            emailEnabled?: Maybe<boolean>;
            usernameEnabled?: Maybe<boolean>;
        }>;
        customSMSProvider?: Maybe<{
            enabled?: Maybe<boolean>;
            provider?: Maybe<string>;
            config?: Maybe<string>;
        }>;
    };
};
export declare type AccessTokenVariables = Exact<{
    userPoolId: Scalars['String'];
    secret: Scalars['String'];
}>;
export declare type AccessTokenResponse = {
    accessToken: {
        accessToken?: Maybe<string>;
        exp?: Maybe<number>;
        iat?: Maybe<number>;
    };
};
export declare type ArchivedUsersVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
}>;
export declare type ArchivedUsersResponse = {
    archivedUsers: {
        totalCount: number;
        list: Array<{
            id: string;
            arn: string;
            status?: Maybe<UserStatus>;
            userPoolId: string;
            username?: Maybe<string>;
            email?: Maybe<string>;
            emailVerified?: Maybe<boolean>;
            phone?: Maybe<string>;
            phoneVerified?: Maybe<boolean>;
            unionid?: Maybe<string>;
            openid?: Maybe<string>;
            nickname?: Maybe<string>;
            registerSource?: Maybe<Array<string>>;
            photo?: Maybe<string>;
            password?: Maybe<string>;
            oauth?: Maybe<string>;
            token?: Maybe<string>;
            tokenExpiredAt?: Maybe<string>;
            loginsCount?: Maybe<number>;
            lastLogin?: Maybe<string>;
            lastIP?: Maybe<string>;
            signedUp?: Maybe<string>;
            blocked?: Maybe<boolean>;
            isDeleted?: Maybe<boolean>;
            device?: Maybe<string>;
            browser?: Maybe<string>;
            company?: Maybe<string>;
            name?: Maybe<string>;
            givenName?: Maybe<string>;
            familyName?: Maybe<string>;
            middleName?: Maybe<string>;
            profile?: Maybe<string>;
            preferredUsername?: Maybe<string>;
            website?: Maybe<string>;
            gender?: Maybe<string>;
            birthdate?: Maybe<string>;
            zoneinfo?: Maybe<string>;
            locale?: Maybe<string>;
            address?: Maybe<string>;
            formatted?: Maybe<string>;
            streetAddress?: Maybe<string>;
            locality?: Maybe<string>;
            region?: Maybe<string>;
            postalCode?: Maybe<string>;
            city?: Maybe<string>;
            province?: Maybe<string>;
            country?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            externalId?: Maybe<string>;
        }>;
    };
};
export declare type AuthorizedTargetsVariables = Exact<{
    namespace: Scalars['String'];
    resourceType: ResourceType;
    resource: Scalars['String'];
    targetType?: Maybe<PolicyAssignmentTargetType>;
    actions?: Maybe<AuthorizedTargetsActionsInput>;
}>;
export declare type AuthorizedTargetsResponse = {
    authorizedTargets?: Maybe<{
        totalCount?: Maybe<number>;
        list?: Maybe<Array<Maybe<{
            targetType?: Maybe<PolicyAssignmentTargetType>;
            targetIdentifier?: Maybe<string>;
            actions?: Maybe<Array<string>>;
        }>>>;
    }>;
};
export declare type CheckLoginStatusVariables = Exact<{
    token?: Maybe<Scalars['String']>;
}>;
export declare type CheckLoginStatusResponse = {
    checkLoginStatus?: Maybe<{
        code?: Maybe<number>;
        message?: Maybe<string>;
        status?: Maybe<boolean>;
        exp?: Maybe<number>;
        iat?: Maybe<number>;
        data?: Maybe<{
            id?: Maybe<string>;
            userPoolId?: Maybe<string>;
            arn?: Maybe<string>;
        }>;
    }>;
};
export declare type CheckPasswordStrengthVariables = Exact<{
    password: Scalars['String'];
}>;
export declare type CheckPasswordStrengthResponse = {
    checkPasswordStrength: {
        valid: boolean;
        message?: Maybe<string>;
    };
};
export declare type ChildrenNodesVariables = Exact<{
    orgId: Scalars['String'];
    nodeId: Scalars['String'];
}>;
export declare type ChildrenNodesResponse = {
    childrenNodes: Array<{
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
    }>;
};
export declare type EmailTemplatesVariables = Exact<{
    [key: string]: never;
}>;
export declare type EmailTemplatesResponse = {
    emailTemplates: Array<{
        type: EmailTemplateType;
        name: string;
        subject: string;
        sender: string;
        content: string;
        redirectTo?: Maybe<string>;
        hasURL?: Maybe<boolean>;
        expiresIn?: Maybe<number>;
        enabled?: Maybe<boolean>;
        isSystem?: Maybe<boolean>;
    }>;
};
export declare type FindUserVariables = Exact<{
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    externalId?: Maybe<Scalars['String']>;
}>;
export declare type FindUserResponse = {
    findUser?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type FunctionVariables = Exact<{
    id?: Maybe<Scalars['String']>;
}>;
export declare type FunctionResponse = {
    function?: Maybe<{
        id: string;
        name: string;
        sourceCode: string;
        description?: Maybe<string>;
        url?: Maybe<string>;
    }>;
};
export declare type FunctionsVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
}>;
export declare type FunctionsResponse = {
    functions: {
        totalCount: number;
        list: Array<{
            id: string;
            name: string;
            sourceCode: string;
            description?: Maybe<string>;
            url?: Maybe<string>;
        }>;
    };
};
export declare type GetUserDepartmentsVariables = Exact<{
    id: Scalars['String'];
    orgId?: Maybe<Scalars['String']>;
}>;
export declare type GetUserDepartmentsResponse = {
    user?: Maybe<{
        departments?: Maybe<{
            totalCount: number;
            list: Array<{
                isMainDepartment: boolean;
                joinedAt?: Maybe<string>;
                department: {
                    id: string;
                    orgId?: Maybe<string>;
                    name: string;
                    nameI18n?: Maybe<string>;
                    description?: Maybe<string>;
                    descriptionI18n?: Maybe<string>;
                    order?: Maybe<number>;
                    code?: Maybe<string>;
                    root?: Maybe<boolean>;
                    depth?: Maybe<number>;
                    path: Array<string>;
                    codePath: Array<Maybe<string>>;
                    namePath: Array<string>;
                    createdAt?: Maybe<string>;
                    updatedAt?: Maybe<string>;
                    children?: Maybe<Array<string>>;
                };
            }>;
        }>;
    }>;
};
export declare type GetUserGroupsVariables = Exact<{
    id: Scalars['String'];
}>;
export declare type GetUserGroupsResponse = {
    user?: Maybe<{
        groups?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                name: string;
                description?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
            }>;
        }>;
    }>;
};
export declare type GetUserRolesVariables = Exact<{
    id: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type GetUserRolesResponse = {
    user?: Maybe<{
        roles?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                namespace: string;
                arn: string;
                description?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                parent?: Maybe<{
                    code: string;
                    namespace: string;
                    arn: string;
                    description?: Maybe<string>;
                    createdAt?: Maybe<string>;
                    updatedAt?: Maybe<string>;
                }>;
            }>;
        }>;
    }>;
};
export declare type GroupVariables = Exact<{
    code: Scalars['String'];
}>;
export declare type GroupResponse = {
    group?: Maybe<{
        code: string;
        name: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
    }>;
};
export declare type GroupWithUsersVariables = Exact<{
    code: Scalars['String'];
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
}>;
export declare type GroupWithUsersResponse = {
    group?: Maybe<{
        users: {
            totalCount: number;
            list: Array<{
                id: string;
                arn: string;
                userPoolId: string;
                username?: Maybe<string>;
                email?: Maybe<string>;
                emailVerified?: Maybe<boolean>;
                phone?: Maybe<string>;
                phoneVerified?: Maybe<boolean>;
                unionid?: Maybe<string>;
                openid?: Maybe<string>;
                nickname?: Maybe<string>;
                registerSource?: Maybe<Array<string>>;
                photo?: Maybe<string>;
                password?: Maybe<string>;
                oauth?: Maybe<string>;
                token?: Maybe<string>;
                tokenExpiredAt?: Maybe<string>;
                loginsCount?: Maybe<number>;
                lastLogin?: Maybe<string>;
                lastIP?: Maybe<string>;
                signedUp?: Maybe<string>;
                blocked?: Maybe<boolean>;
                isDeleted?: Maybe<boolean>;
                device?: Maybe<string>;
                browser?: Maybe<string>;
                company?: Maybe<string>;
                name?: Maybe<string>;
                givenName?: Maybe<string>;
                familyName?: Maybe<string>;
                middleName?: Maybe<string>;
                profile?: Maybe<string>;
                preferredUsername?: Maybe<string>;
                website?: Maybe<string>;
                gender?: Maybe<string>;
                birthdate?: Maybe<string>;
                zoneinfo?: Maybe<string>;
                locale?: Maybe<string>;
                address?: Maybe<string>;
                formatted?: Maybe<string>;
                streetAddress?: Maybe<string>;
                locality?: Maybe<string>;
                region?: Maybe<string>;
                postalCode?: Maybe<string>;
                city?: Maybe<string>;
                province?: Maybe<string>;
                country?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                externalId?: Maybe<string>;
            }>;
        };
    }>;
};
export declare type GroupsVariables = Exact<{
    userId?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
}>;
export declare type GroupsResponse = {
    groups: {
        totalCount: number;
        list: Array<{
            code: string;
            name: string;
            description?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
        }>;
    };
};
export declare type IsActionAllowedVariables = Exact<{
    resource: Scalars['String'];
    action: Scalars['String'];
    userId: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type IsActionAllowedResponse = {
    isActionAllowed: boolean;
};
export declare type IsActionDeniedVariables = Exact<{
    resource: Scalars['String'];
    action: Scalars['String'];
    userId: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type IsActionDeniedResponse = {
    isActionDenied: boolean;
};
export declare type IsDomainAvaliableVariables = Exact<{
    domain: Scalars['String'];
}>;
export declare type IsDomainAvaliableResponse = {
    isDomainAvaliable?: Maybe<boolean>;
};
export declare type IsRootNodeVariables = Exact<{
    nodeId: Scalars['String'];
    orgId: Scalars['String'];
}>;
export declare type IsRootNodeResponse = {
    isRootNode?: Maybe<boolean>;
};
export declare type IsUserExistsVariables = Exact<{
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    externalId?: Maybe<Scalars['String']>;
}>;
export declare type IsUserExistsResponse = {
    isUserExists?: Maybe<boolean>;
};
export declare type AuthorizedResourcesVariables = Exact<{
    targetType?: Maybe<PolicyAssignmentTargetType>;
    targetIdentifier?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
}>;
export declare type AuthorizedResourcesResponse = {
    authorizedResources?: Maybe<{
        totalCount: number;
        list: Array<{
            code: string;
            type?: Maybe<ResourceType>;
            actions?: Maybe<Array<string>>;
        }>;
    }>;
};
export declare type ListGroupAuthorizedResourcesVariables = Exact<{
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
}>;
export declare type ListGroupAuthorizedResourcesResponse = {
    group?: Maybe<{
        authorizedResources?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                type?: Maybe<ResourceType>;
                actions?: Maybe<Array<string>>;
            }>;
        }>;
    }>;
};
export declare type ListNodeByCodeAuthorizedResourcesVariables = Exact<{
    orgId: Scalars['String'];
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
}>;
export declare type ListNodeByCodeAuthorizedResourcesResponse = {
    nodeByCode?: Maybe<{
        authorizedResources?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                type?: Maybe<ResourceType>;
                actions?: Maybe<Array<string>>;
            }>;
        }>;
    }>;
};
export declare type ListNodeByIdAuthorizedResourcesVariables = Exact<{
    id: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
}>;
export declare type ListNodeByIdAuthorizedResourcesResponse = {
    nodeById?: Maybe<{
        authorizedResources?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                type?: Maybe<ResourceType>;
                actions?: Maybe<Array<string>>;
            }>;
        }>;
    }>;
};
export declare type ListRoleAuthorizedResourcesVariables = Exact<{
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
}>;
export declare type ListRoleAuthorizedResourcesResponse = {
    role?: Maybe<{
        authorizedResources?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                type?: Maybe<ResourceType>;
                actions?: Maybe<Array<string>>;
            }>;
        }>;
    }>;
};
export declare type ListUserAuthorizedResourcesVariables = Exact<{
    id: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
    resourceType?: Maybe<Scalars['String']>;
}>;
export declare type ListUserAuthorizedResourcesResponse = {
    user?: Maybe<{
        authorizedResources?: Maybe<{
            totalCount: number;
            list: Array<{
                code: string;
                type?: Maybe<ResourceType>;
                actions?: Maybe<Array<string>>;
            }>;
        }>;
    }>;
};
export declare type NodeByCodeVariables = Exact<{
    orgId: Scalars['String'];
    code: Scalars['String'];
}>;
export declare type NodeByCodeResponse = {
    nodeByCode?: Maybe<{
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
    }>;
};
export declare type NodeByCodeWithMembersVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
    includeChildrenNodes?: Maybe<Scalars['Boolean']>;
    orgId: Scalars['String'];
    code: Scalars['String'];
}>;
export declare type NodeByCodeWithMembersResponse = {
    nodeByCode?: Maybe<{
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
        users: {
            totalCount: number;
            list: Array<{
                id: string;
                arn: string;
                userPoolId: string;
                status?: Maybe<UserStatus>;
                username?: Maybe<string>;
                email?: Maybe<string>;
                emailVerified?: Maybe<boolean>;
                phone?: Maybe<string>;
                phoneVerified?: Maybe<boolean>;
                unionid?: Maybe<string>;
                openid?: Maybe<string>;
                nickname?: Maybe<string>;
                registerSource?: Maybe<Array<string>>;
                photo?: Maybe<string>;
                password?: Maybe<string>;
                oauth?: Maybe<string>;
                token?: Maybe<string>;
                tokenExpiredAt?: Maybe<string>;
                loginsCount?: Maybe<number>;
                lastLogin?: Maybe<string>;
                lastIP?: Maybe<string>;
                signedUp?: Maybe<string>;
                blocked?: Maybe<boolean>;
                isDeleted?: Maybe<boolean>;
                device?: Maybe<string>;
                browser?: Maybe<string>;
                company?: Maybe<string>;
                name?: Maybe<string>;
                givenName?: Maybe<string>;
                familyName?: Maybe<string>;
                middleName?: Maybe<string>;
                profile?: Maybe<string>;
                preferredUsername?: Maybe<string>;
                website?: Maybe<string>;
                gender?: Maybe<string>;
                birthdate?: Maybe<string>;
                zoneinfo?: Maybe<string>;
                locale?: Maybe<string>;
                address?: Maybe<string>;
                formatted?: Maybe<string>;
                streetAddress?: Maybe<string>;
                locality?: Maybe<string>;
                region?: Maybe<string>;
                postalCode?: Maybe<string>;
                city?: Maybe<string>;
                province?: Maybe<string>;
                country?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                externalId?: Maybe<string>;
            }>;
        };
    }>;
};
export declare type NodeByIdVariables = Exact<{
    id: Scalars['String'];
}>;
export declare type NodeByIdResponse = {
    nodeById?: Maybe<{
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
    }>;
};
export declare type NodeByIdWithMembersVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
    includeChildrenNodes?: Maybe<Scalars['Boolean']>;
    id: Scalars['String'];
}>;
export declare type NodeByIdWithMembersResponse = {
    nodeById?: Maybe<{
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
        users: {
            totalCount: number;
            list: Array<{
                id: string;
                arn: string;
                userPoolId: string;
                status?: Maybe<UserStatus>;
                username?: Maybe<string>;
                email?: Maybe<string>;
                emailVerified?: Maybe<boolean>;
                phone?: Maybe<string>;
                phoneVerified?: Maybe<boolean>;
                unionid?: Maybe<string>;
                openid?: Maybe<string>;
                nickname?: Maybe<string>;
                registerSource?: Maybe<Array<string>>;
                photo?: Maybe<string>;
                password?: Maybe<string>;
                oauth?: Maybe<string>;
                token?: Maybe<string>;
                tokenExpiredAt?: Maybe<string>;
                loginsCount?: Maybe<number>;
                lastLogin?: Maybe<string>;
                lastIP?: Maybe<string>;
                signedUp?: Maybe<string>;
                blocked?: Maybe<boolean>;
                isDeleted?: Maybe<boolean>;
                device?: Maybe<string>;
                browser?: Maybe<string>;
                company?: Maybe<string>;
                name?: Maybe<string>;
                givenName?: Maybe<string>;
                familyName?: Maybe<string>;
                middleName?: Maybe<string>;
                profile?: Maybe<string>;
                preferredUsername?: Maybe<string>;
                website?: Maybe<string>;
                gender?: Maybe<string>;
                birthdate?: Maybe<string>;
                zoneinfo?: Maybe<string>;
                locale?: Maybe<string>;
                address?: Maybe<string>;
                formatted?: Maybe<string>;
                streetAddress?: Maybe<string>;
                locality?: Maybe<string>;
                region?: Maybe<string>;
                postalCode?: Maybe<string>;
                city?: Maybe<string>;
                province?: Maybe<string>;
                country?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                externalId?: Maybe<string>;
            }>;
        };
    }>;
};
export declare type OrgVariables = Exact<{
    id: Scalars['String'];
}>;
export declare type OrgResponse = {
    org: {
        id: string;
        rootNode: {
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        };
        nodes: Array<{
            id: string;
            orgId?: Maybe<string>;
            name: string;
            nameI18n?: Maybe<string>;
            description?: Maybe<string>;
            descriptionI18n?: Maybe<string>;
            order?: Maybe<number>;
            code?: Maybe<string>;
            root?: Maybe<boolean>;
            depth?: Maybe<number>;
            path: Array<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            children?: Maybe<Array<string>>;
        }>;
    };
};
export declare type OrgsVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
}>;
export declare type OrgsResponse = {
    orgs: {
        totalCount: number;
        list: Array<{
            id: string;
            rootNode: {
                id: string;
                name: string;
                nameI18n?: Maybe<string>;
                path: Array<string>;
                description?: Maybe<string>;
                descriptionI18n?: Maybe<string>;
                order?: Maybe<number>;
                code?: Maybe<string>;
                root?: Maybe<boolean>;
                depth?: Maybe<number>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                children?: Maybe<Array<string>>;
            };
            nodes: Array<{
                id: string;
                name: string;
                path: Array<string>;
                nameI18n?: Maybe<string>;
                description?: Maybe<string>;
                descriptionI18n?: Maybe<string>;
                order?: Maybe<number>;
                code?: Maybe<string>;
                root?: Maybe<boolean>;
                depth?: Maybe<number>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                children?: Maybe<Array<string>>;
            }>;
        }>;
    };
};
export declare type PoliciesVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type PoliciesResponse = {
    policies: {
        totalCount: number;
        list: Array<{
            namespace: string;
            code: string;
            description?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            statements: Array<{
                resource: string;
                actions: Array<string>;
                effect?: Maybe<PolicyEffect>;
                condition?: Maybe<Array<{
                    param: string;
                    operator: string;
                    value: any;
                }>>;
            }>;
        }>;
    };
};
export declare type PolicyVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    code: Scalars['String'];
}>;
export declare type PolicyResponse = {
    policy?: Maybe<{
        namespace: string;
        code: string;
        isDefault: boolean;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        statements: Array<{
            resource: string;
            actions: Array<string>;
            effect?: Maybe<PolicyEffect>;
            condition?: Maybe<Array<{
                param: string;
                operator: string;
                value: any;
            }>>;
        }>;
    }>;
};
export declare type PolicyAssignmentsVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    code?: Maybe<Scalars['String']>;
    targetType?: Maybe<PolicyAssignmentTargetType>;
    targetIdentifier?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
}>;
export declare type PolicyAssignmentsResponse = {
    policyAssignments: {
        totalCount: number;
        list: Array<{
            code: string;
            targetType: PolicyAssignmentTargetType;
            targetIdentifier: string;
        }>;
    };
};
export declare type PolicyWithAssignmentsVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    code: Scalars['String'];
}>;
export declare type PolicyWithAssignmentsResponse = {
    policy?: Maybe<{
        code: string;
        isDefault: boolean;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        assignmentsCount: number;
        statements: Array<{
            resource: string;
            actions: Array<string>;
            effect?: Maybe<PolicyEffect>;
        }>;
        assignments: Array<{
            code: string;
            targetType: PolicyAssignmentTargetType;
            targetIdentifier: string;
        }>;
    }>;
};
export declare type PreviewEmailVariables = Exact<{
    type: EmailTemplateType;
}>;
export declare type PreviewEmailResponse = {
    previewEmail: string;
};
export declare type QiniuUptokenVariables = Exact<{
    type?: Maybe<Scalars['String']>;
}>;
export declare type QiniuUptokenResponse = {
    qiniuUptoken?: Maybe<string>;
};
export declare type QueryMfaVariables = Exact<{
    id?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    userPoolId?: Maybe<Scalars['String']>;
}>;
export declare type QueryMfaResponse = {
    queryMfa?: Maybe<{
        id: string;
        userId: string;
        userPoolId: string;
        enable: boolean;
        secret?: Maybe<string>;
    }>;
};
export declare type RoleVariables = Exact<{
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type RoleResponse = {
    role?: Maybe<{
        namespace: string;
        code: string;
        arn: string;
        description?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        parent?: Maybe<{
            namespace: string;
            code: string;
            arn: string;
            description?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
        }>;
    }>;
};
export declare type RoleWithUsersVariables = Exact<{
    code: Scalars['String'];
    namespace?: Maybe<Scalars['String']>;
}>;
export declare type RoleWithUsersResponse = {
    role?: Maybe<{
        users: {
            totalCount: number;
            list: Array<{
                id: string;
                arn: string;
                status?: Maybe<UserStatus>;
                userPoolId: string;
                username?: Maybe<string>;
                email?: Maybe<string>;
                emailVerified?: Maybe<boolean>;
                phone?: Maybe<string>;
                phoneVerified?: Maybe<boolean>;
                unionid?: Maybe<string>;
                openid?: Maybe<string>;
                nickname?: Maybe<string>;
                registerSource?: Maybe<Array<string>>;
                photo?: Maybe<string>;
                password?: Maybe<string>;
                oauth?: Maybe<string>;
                token?: Maybe<string>;
                tokenExpiredAt?: Maybe<string>;
                loginsCount?: Maybe<number>;
                lastLogin?: Maybe<string>;
                lastIP?: Maybe<string>;
                signedUp?: Maybe<string>;
                blocked?: Maybe<boolean>;
                isDeleted?: Maybe<boolean>;
                device?: Maybe<string>;
                browser?: Maybe<string>;
                company?: Maybe<string>;
                name?: Maybe<string>;
                givenName?: Maybe<string>;
                familyName?: Maybe<string>;
                middleName?: Maybe<string>;
                profile?: Maybe<string>;
                preferredUsername?: Maybe<string>;
                website?: Maybe<string>;
                gender?: Maybe<string>;
                birthdate?: Maybe<string>;
                zoneinfo?: Maybe<string>;
                locale?: Maybe<string>;
                address?: Maybe<string>;
                formatted?: Maybe<string>;
                streetAddress?: Maybe<string>;
                locality?: Maybe<string>;
                region?: Maybe<string>;
                postalCode?: Maybe<string>;
                city?: Maybe<string>;
                province?: Maybe<string>;
                country?: Maybe<string>;
                createdAt?: Maybe<string>;
                updatedAt?: Maybe<string>;
                externalId?: Maybe<string>;
            }>;
        };
    }>;
};
export declare type RolesVariables = Exact<{
    namespace?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
}>;
export declare type RolesResponse = {
    roles: {
        totalCount: number;
        list: Array<{
            namespace: string;
            code: string;
            arn: string;
            description?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
        }>;
    };
};
export declare type RootNodeVariables = Exact<{
    orgId: Scalars['String'];
}>;
export declare type RootNodeResponse = {
    rootNode: {
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        codePath: Array<Maybe<string>>;
        namePath: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
    };
};
export declare type SearchNodesVariables = Exact<{
    keyword: Scalars['String'];
}>;
export declare type SearchNodesResponse = {
    searchNodes: Array<{
        id: string;
        orgId?: Maybe<string>;
        name: string;
        nameI18n?: Maybe<string>;
        description?: Maybe<string>;
        descriptionI18n?: Maybe<string>;
        order?: Maybe<number>;
        code?: Maybe<string>;
        root?: Maybe<boolean>;
        depth?: Maybe<number>;
        path: Array<string>;
        codePath: Array<Maybe<string>>;
        namePath: Array<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        children?: Maybe<Array<string>>;
    }>;
};
export declare type SearchUserVariables = Exact<{
    query: Scalars['String'];
    fields?: Maybe<Array<Maybe<Scalars['String']>>>;
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    departmentOpts?: Maybe<Array<Maybe<SearchUserDepartmentOpt>>>;
    groupOpts?: Maybe<Array<Maybe<SearchUserGroupOpt>>>;
    roleOpts?: Maybe<Array<Maybe<SearchUserRoleOpt>>>;
}>;
export declare type SearchUserResponse = {
    searchUser: {
        totalCount: number;
        list: Array<{
            id: string;
            arn: string;
            userPoolId: string;
            status?: Maybe<UserStatus>;
            username?: Maybe<string>;
            email?: Maybe<string>;
            emailVerified?: Maybe<boolean>;
            phone?: Maybe<string>;
            phoneVerified?: Maybe<boolean>;
            unionid?: Maybe<string>;
            openid?: Maybe<string>;
            nickname?: Maybe<string>;
            registerSource?: Maybe<Array<string>>;
            photo?: Maybe<string>;
            password?: Maybe<string>;
            oauth?: Maybe<string>;
            token?: Maybe<string>;
            tokenExpiredAt?: Maybe<string>;
            loginsCount?: Maybe<number>;
            lastLogin?: Maybe<string>;
            lastIP?: Maybe<string>;
            signedUp?: Maybe<string>;
            blocked?: Maybe<boolean>;
            isDeleted?: Maybe<boolean>;
            device?: Maybe<string>;
            browser?: Maybe<string>;
            company?: Maybe<string>;
            name?: Maybe<string>;
            givenName?: Maybe<string>;
            familyName?: Maybe<string>;
            middleName?: Maybe<string>;
            profile?: Maybe<string>;
            preferredUsername?: Maybe<string>;
            website?: Maybe<string>;
            gender?: Maybe<string>;
            birthdate?: Maybe<string>;
            zoneinfo?: Maybe<string>;
            locale?: Maybe<string>;
            address?: Maybe<string>;
            formatted?: Maybe<string>;
            streetAddress?: Maybe<string>;
            locality?: Maybe<string>;
            region?: Maybe<string>;
            postalCode?: Maybe<string>;
            city?: Maybe<string>;
            province?: Maybe<string>;
            country?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            externalId?: Maybe<string>;
        }>;
    };
};
export declare type SocialConnectionVariables = Exact<{
    provider: Scalars['String'];
}>;
export declare type SocialConnectionResponse = {
    socialConnection?: Maybe<{
        provider: string;
        name: string;
        logo: string;
        description?: Maybe<string>;
        fields?: Maybe<Array<{
            key?: Maybe<string>;
            label?: Maybe<string>;
            type?: Maybe<string>;
            placeholder?: Maybe<string>;
        }>>;
    }>;
};
export declare type SocialConnectionInstanceVariables = Exact<{
    provider: Scalars['String'];
}>;
export declare type SocialConnectionInstanceResponse = {
    socialConnectionInstance: {
        provider: string;
        enabled: boolean;
        fields?: Maybe<Array<Maybe<{
            key: string;
            value: string;
        }>>>;
    };
};
export declare type SocialConnectionInstancesVariables = Exact<{
    [key: string]: never;
}>;
export declare type SocialConnectionInstancesResponse = {
    socialConnectionInstances: Array<{
        provider: string;
        enabled: boolean;
        fields?: Maybe<Array<Maybe<{
            key: string;
            value: string;
        }>>>;
    }>;
};
export declare type SocialConnectionsVariables = Exact<{
    [key: string]: never;
}>;
export declare type SocialConnectionsResponse = {
    socialConnections: Array<{
        provider: string;
        name: string;
        logo: string;
        description?: Maybe<string>;
        fields?: Maybe<Array<{
            key?: Maybe<string>;
            label?: Maybe<string>;
            type?: Maybe<string>;
            placeholder?: Maybe<string>;
        }>>;
    }>;
};
export declare type TemplateCodeVariables = Exact<{
    [key: string]: never;
}>;
export declare type TemplateCodeResponse = {
    templateCode: string;
};
export declare type UdfVariables = Exact<{
    targetType: UdfTargetType;
}>;
export declare type UdfResponse = {
    udf: Array<{
        targetType: UdfTargetType;
        dataType: UdfDataType;
        key: string;
        label?: Maybe<string>;
        options?: Maybe<string>;
    }>;
};
export declare type UdfValueBatchVariables = Exact<{
    targetType: UdfTargetType;
    targetIds: Array<Scalars['String']>;
}>;
export declare type UdfValueBatchResponse = {
    udfValueBatch: Array<{
        targetId: string;
        data: Array<{
            key: string;
            dataType: UdfDataType;
            value: string;
            label?: Maybe<string>;
        }>;
    }>;
};
export declare type UdvVariables = Exact<{
    targetType: UdfTargetType;
    targetId: Scalars['String'];
}>;
export declare type UdvResponse = {
    udv: Array<{
        key: string;
        dataType: UdfDataType;
        value: string;
        label?: Maybe<string>;
    }>;
};
export declare type UserVariables = Exact<{
    id?: Maybe<Scalars['String']>;
}>;
export declare type UserResponse = {
    user?: Maybe<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
        identities?: Maybe<Array<Maybe<{
            openid?: Maybe<string>;
            userIdInIdp?: Maybe<string>;
            userId?: Maybe<string>;
            connectionId?: Maybe<string>;
            isSocial?: Maybe<boolean>;
            provider?: Maybe<string>;
            userPoolId?: Maybe<string>;
        }>>>;
    }>;
};
export declare type UserBatchVariables = Exact<{
    ids: Array<Scalars['String']>;
}>;
export declare type UserBatchResponse = {
    userBatch: Array<{
        id: string;
        arn: string;
        userPoolId: string;
        status?: Maybe<UserStatus>;
        username?: Maybe<string>;
        email?: Maybe<string>;
        emailVerified?: Maybe<boolean>;
        phone?: Maybe<string>;
        phoneVerified?: Maybe<boolean>;
        unionid?: Maybe<string>;
        openid?: Maybe<string>;
        nickname?: Maybe<string>;
        registerSource?: Maybe<Array<string>>;
        photo?: Maybe<string>;
        password?: Maybe<string>;
        oauth?: Maybe<string>;
        token?: Maybe<string>;
        tokenExpiredAt?: Maybe<string>;
        loginsCount?: Maybe<number>;
        lastLogin?: Maybe<string>;
        lastIP?: Maybe<string>;
        signedUp?: Maybe<string>;
        blocked?: Maybe<boolean>;
        isDeleted?: Maybe<boolean>;
        device?: Maybe<string>;
        browser?: Maybe<string>;
        company?: Maybe<string>;
        name?: Maybe<string>;
        givenName?: Maybe<string>;
        familyName?: Maybe<string>;
        middleName?: Maybe<string>;
        profile?: Maybe<string>;
        preferredUsername?: Maybe<string>;
        website?: Maybe<string>;
        gender?: Maybe<string>;
        birthdate?: Maybe<string>;
        zoneinfo?: Maybe<string>;
        locale?: Maybe<string>;
        address?: Maybe<string>;
        formatted?: Maybe<string>;
        streetAddress?: Maybe<string>;
        locality?: Maybe<string>;
        region?: Maybe<string>;
        postalCode?: Maybe<string>;
        city?: Maybe<string>;
        province?: Maybe<string>;
        country?: Maybe<string>;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        externalId?: Maybe<string>;
    }>;
};
export declare type UserpoolVariables = Exact<{
    [key: string]: never;
}>;
export declare type UserpoolResponse = {
    userpool: {
        id: string;
        name: string;
        domain: string;
        description?: Maybe<string>;
        secret: string;
        jwtSecret: string;
        ownerId?: Maybe<string>;
        logo: string;
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        emailVerifiedDefault: boolean;
        sendWelcomeEmail: boolean;
        registerDisabled: boolean;
        appSsoEnabled: boolean;
        showWxQRCodeWhenRegisterDisabled?: Maybe<boolean>;
        allowedOrigins?: Maybe<string>;
        tokenExpiresAfter?: Maybe<number>;
        isDeleted?: Maybe<boolean>;
        packageType?: Maybe<number>;
        useCustomUserStore?: Maybe<boolean>;
        loginRequireEmailVerified?: Maybe<boolean>;
        verifyCodeLength?: Maybe<number>;
        userpoolTypes?: Maybe<Array<{
            code?: Maybe<string>;
            name?: Maybe<string>;
            description?: Maybe<string>;
            image?: Maybe<string>;
            sdks?: Maybe<Array<Maybe<string>>>;
        }>>;
        frequentRegisterCheck?: Maybe<{
            timeInterval?: Maybe<number>;
            limit?: Maybe<number>;
            enabled?: Maybe<boolean>;
        }>;
        loginFailCheck?: Maybe<{
            timeInterval?: Maybe<number>;
            limit?: Maybe<number>;
            enabled?: Maybe<boolean>;
        }>;
        changePhoneStrategy?: Maybe<{
            verifyOldPhone?: Maybe<boolean>;
        }>;
        changeEmailStrategy?: Maybe<{
            verifyOldEmail?: Maybe<boolean>;
        }>;
        qrcodeLoginStrategy?: Maybe<{
            qrcodeExpiresAfter?: Maybe<number>;
            returnFullUserInfo?: Maybe<boolean>;
            allowExchangeUserInfoFromBrowser?: Maybe<boolean>;
            ticketExpiresAfter?: Maybe<number>;
        }>;
        app2WxappLoginStrategy?: Maybe<{
            ticketExpriresAfter?: Maybe<number>;
            ticketExchangeUserInfoNeedSecret?: Maybe<boolean>;
        }>;
        whitelist?: Maybe<{
            phoneEnabled?: Maybe<boolean>;
            emailEnabled?: Maybe<boolean>;
            usernameEnabled?: Maybe<boolean>;
        }>;
        customSMSProvider?: Maybe<{
            enabled?: Maybe<boolean>;
            provider?: Maybe<string>;
            config?: Maybe<string>;
        }>;
    };
};
export declare type UserpoolTypesVariables = Exact<{
    [key: string]: never;
}>;
export declare type UserpoolTypesResponse = {
    userpoolTypes: Array<{
        code?: Maybe<string>;
        name?: Maybe<string>;
        description?: Maybe<string>;
        image?: Maybe<string>;
        sdks?: Maybe<Array<Maybe<string>>>;
    }>;
};
export declare type UserpoolsVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
}>;
export declare type UserpoolsResponse = {
    userpools: {
        totalCount: number;
        list: Array<{
            id: string;
            name: string;
            domain: string;
            ownerId?: Maybe<string>;
            description?: Maybe<string>;
            secret: string;
            jwtSecret: string;
            logo: string;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            emailVerifiedDefault: boolean;
            sendWelcomeEmail: boolean;
            registerDisabled: boolean;
            appSsoEnabled: boolean;
            showWxQRCodeWhenRegisterDisabled?: Maybe<boolean>;
            allowedOrigins?: Maybe<string>;
            tokenExpiresAfter?: Maybe<number>;
            isDeleted?: Maybe<boolean>;
            packageType?: Maybe<number>;
            useCustomUserStore?: Maybe<boolean>;
            loginRequireEmailVerified?: Maybe<boolean>;
            verifyCodeLength?: Maybe<number>;
        }>;
    };
};
export declare type UsersVariables = Exact<{
    page?: Maybe<Scalars['Int']>;
    limit?: Maybe<Scalars['Int']>;
    sortBy?: Maybe<SortByEnum>;
}>;
export declare type UsersResponse = {
    users: {
        totalCount: number;
        list: Array<{
            id: string;
            arn: string;
            userPoolId: string;
            status?: Maybe<UserStatus>;
            username?: Maybe<string>;
            email?: Maybe<string>;
            emailVerified?: Maybe<boolean>;
            phone?: Maybe<string>;
            phoneVerified?: Maybe<boolean>;
            unionid?: Maybe<string>;
            openid?: Maybe<string>;
            nickname?: Maybe<string>;
            registerSource?: Maybe<Array<string>>;
            photo?: Maybe<string>;
            password?: Maybe<string>;
            oauth?: Maybe<string>;
            token?: Maybe<string>;
            tokenExpiredAt?: Maybe<string>;
            loginsCount?: Maybe<number>;
            lastLogin?: Maybe<string>;
            lastIP?: Maybe<string>;
            signedUp?: Maybe<string>;
            blocked?: Maybe<boolean>;
            isDeleted?: Maybe<boolean>;
            device?: Maybe<string>;
            browser?: Maybe<string>;
            company?: Maybe<string>;
            name?: Maybe<string>;
            givenName?: Maybe<string>;
            familyName?: Maybe<string>;
            middleName?: Maybe<string>;
            profile?: Maybe<string>;
            preferredUsername?: Maybe<string>;
            website?: Maybe<string>;
            gender?: Maybe<string>;
            birthdate?: Maybe<string>;
            zoneinfo?: Maybe<string>;
            locale?: Maybe<string>;
            address?: Maybe<string>;
            formatted?: Maybe<string>;
            streetAddress?: Maybe<string>;
            locality?: Maybe<string>;
            region?: Maybe<string>;
            postalCode?: Maybe<string>;
            city?: Maybe<string>;
            province?: Maybe<string>;
            country?: Maybe<string>;
            createdAt?: Maybe<string>;
            updatedAt?: Maybe<string>;
            externalId?: Maybe<string>;
        }>;
    };
};
export declare type WhitelistVariables = Exact<{
    type: WhitelistType;
}>;
export declare type WhitelistResponse = {
    whitelist: Array<{
        createdAt?: Maybe<string>;
        updatedAt?: Maybe<string>;
        value: string;
    }>;
};
export declare const AddMemberDocument = "\n    mutation addMember($page: Int, $limit: Int, $sortBy: SortByEnum, $includeChildrenNodes: Boolean, $nodeId: String, $orgId: String, $nodeCode: String, $userIds: [String!]!, $isLeader: Boolean) {\n  addMember(nodeId: $nodeId, orgId: $orgId, nodeCode: $nodeCode, userIds: $userIds, isLeader: $isLeader) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    createdAt\n    updatedAt\n    children\n    users(page: $page, limit: $limit, sortBy: $sortBy, includeChildrenNodes: $includeChildrenNodes) {\n      totalCount\n      list {\n        id\n        arn\n        userPoolId\n        username\n        status\n        email\n        emailVerified\n        phone\n        phoneVerified\n        unionid\n        openid\n        nickname\n        registerSource\n        photo\n        password\n        oauth\n        token\n        tokenExpiredAt\n        loginsCount\n        lastLogin\n        lastIP\n        signedUp\n        blocked\n        isDeleted\n        device\n        browser\n        company\n        name\n        givenName\n        familyName\n        middleName\n        profile\n        preferredUsername\n        website\n        gender\n        birthdate\n        zoneinfo\n        locale\n        address\n        formatted\n        streetAddress\n        locality\n        region\n        postalCode\n        city\n        province\n        country\n        createdAt\n        updatedAt\n        externalId\n      }\n    }\n  }\n}\n    ";
export declare const AddNodeDocument = "\n    mutation addNode($orgId: String!, $parentNodeId: String, $name: String!, $nameI18n: String, $description: String, $descriptionI18n: String, $order: Int, $code: String) {\n  addNode(orgId: $orgId, parentNodeId: $parentNodeId, name: $name, nameI18n: $nameI18n, description: $description, descriptionI18n: $descriptionI18n, order: $order, code: $code) {\n    id\n    rootNode {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n    nodes {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n  }\n}\n    ";
export declare const AddNodeV2Document = "\n    mutation addNodeV2($orgId: String!, $parentNodeId: String, $name: String!, $nameI18n: String, $description: String, $descriptionI18n: String, $order: Int, $code: String) {\n  addNodeV2(orgId: $orgId, parentNodeId: $parentNodeId, name: $name, nameI18n: $nameI18n, description: $description, descriptionI18n: $descriptionI18n, order: $order, code: $code) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    createdAt\n    updatedAt\n    children\n  }\n}\n    ";
export declare const AddPolicyAssignmentsDocument = "\n    mutation addPolicyAssignments($policies: [String!]!, $targetType: PolicyAssignmentTargetType!, $targetIdentifiers: [String!], $inheritByChildren: Boolean, $namespace: String) {\n  addPolicyAssignments(policies: $policies, targetType: $targetType, targetIdentifiers: $targetIdentifiers, inheritByChildren: $inheritByChildren, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const AddUserToGroupDocument = "\n    mutation addUserToGroup($userIds: [String!]!, $code: String) {\n  addUserToGroup(userIds: $userIds, code: $code) {\n    message\n    code\n  }\n}\n    ";
export declare const AddWhitelistDocument = "\n    mutation addWhitelist($type: WhitelistType!, $list: [String!]!) {\n  addWhitelist(type: $type, list: $list) {\n    createdAt\n    updatedAt\n    value\n  }\n}\n    ";
export declare const AllowDocument = "\n    mutation allow($resource: String!, $action: String!, $userId: String, $userIds: [String!], $roleCode: String, $roleCodes: [String!], $namespace: String) {\n  allow(resource: $resource, action: $action, userId: $userId, userIds: $userIds, roleCode: $roleCode, roleCodes: $roleCodes, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const AssignRoleDocument = "\n    mutation assignRole($namespace: String, $roleCode: String, $roleCodes: [String], $userIds: [String!], $groupCodes: [String!], $nodeCodes: [String!]) {\n  assignRole(namespace: $namespace, roleCode: $roleCode, roleCodes: $roleCodes, userIds: $userIds, groupCodes: $groupCodes, nodeCodes: $nodeCodes) {\n    message\n    code\n  }\n}\n    ";
export declare const AuthorizeResourceDocument = "\n    mutation authorizeResource($namespace: String, $resource: String, $resourceType: ResourceType, $opts: [AuthorizeResourceOpt]) {\n  authorizeResource(namespace: $namespace, resource: $resource, resourceType: $resourceType, opts: $opts) {\n    code\n    message\n  }\n}\n    ";
export declare const BindEmailDocument = "\n    mutation bindEmail($email: String!, $emailCode: String!) {\n  bindEmail(email: $email, emailCode: $emailCode) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const BindPhoneDocument = "\n    mutation bindPhone($phone: String!, $phoneCode: String!) {\n  bindPhone(phone: $phone, phoneCode: $phoneCode) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const ChangeMfaDocument = "\n    mutation changeMfa($enable: Boolean, $id: String, $userId: String, $userPoolId: String, $refresh: Boolean) {\n  changeMfa(enable: $enable, id: $id, userId: $userId, userPoolId: $userPoolId, refresh: $refresh) {\n    id\n    userId\n    userPoolId\n    enable\n    secret\n  }\n}\n    ";
export declare const ConfigEmailTemplateDocument = "\n    mutation configEmailTemplate($input: ConfigEmailTemplateInput!) {\n  configEmailTemplate(input: $input) {\n    type\n    name\n    subject\n    sender\n    content\n    redirectTo\n    hasURL\n    expiresIn\n    enabled\n    isSystem\n  }\n}\n    ";
export declare const CreateFunctionDocument = "\n    mutation createFunction($input: CreateFunctionInput!) {\n  createFunction(input: $input) {\n    id\n    name\n    sourceCode\n    description\n    url\n  }\n}\n    ";
export declare const CreateGroupDocument = "\n    mutation createGroup($code: String!, $name: String!, $description: String) {\n  createGroup(code: $code, name: $name, description: $description) {\n    code\n    name\n    description\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const CreateOrgDocument = "\n    mutation createOrg($name: String!, $code: String, $description: String) {\n  createOrg(name: $name, code: $code, description: $description) {\n    id\n    rootNode {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n    nodes {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n  }\n}\n    ";
export declare const CreatePolicyDocument = "\n    mutation createPolicy($namespace: String, $code: String!, $description: String, $statements: [PolicyStatementInput!]!) {\n  createPolicy(namespace: $namespace, code: $code, description: $description, statements: $statements) {\n    namespace\n    code\n    isDefault\n    description\n    statements {\n      resource\n      actions\n      effect\n      condition {\n        param\n        operator\n        value\n      }\n    }\n    createdAt\n    updatedAt\n    assignmentsCount\n  }\n}\n    ";
export declare const CreateRoleDocument = "\n    mutation createRole($namespace: String, $code: String!, $description: String, $parent: String) {\n  createRole(namespace: $namespace, code: $code, description: $description, parent: $parent) {\n    namespace\n    code\n    arn\n    description\n    createdAt\n    updatedAt\n    parent {\n      namespace\n      code\n      arn\n      description\n      createdAt\n      updatedAt\n    }\n  }\n}\n    ";
export declare const CreateSocialConnectionInstanceDocument = "\n    mutation createSocialConnectionInstance($input: CreateSocialConnectionInstanceInput!) {\n  createSocialConnectionInstance(input: $input) {\n    provider\n    enabled\n    fields {\n      key\n      value\n    }\n  }\n}\n    ";
export declare const CreateUserDocument = "\n    mutation createUser($userInfo: CreateUserInput!, $keepPassword: Boolean) {\n  createUser(userInfo: $userInfo, keepPassword: $keepPassword) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const CreateUserpoolDocument = "\n    mutation createUserpool($name: String!, $domain: String!, $description: String, $logo: String, $userpoolTypes: [String!]) {\n  createUserpool(name: $name, domain: $domain, description: $description, logo: $logo, userpoolTypes: $userpoolTypes) {\n    id\n    name\n    domain\n    description\n    secret\n    jwtSecret\n    userpoolTypes {\n      code\n      name\n      description\n      image\n      sdks\n    }\n    logo\n    createdAt\n    updatedAt\n    emailVerifiedDefault\n    sendWelcomeEmail\n    registerDisabled\n    appSsoEnabled\n    showWxQRCodeWhenRegisterDisabled\n    allowedOrigins\n    tokenExpiresAfter\n    isDeleted\n    frequentRegisterCheck {\n      timeInterval\n      limit\n      enabled\n    }\n    loginFailCheck {\n      timeInterval\n      limit\n      enabled\n    }\n    changePhoneStrategy {\n      verifyOldPhone\n    }\n    changeEmailStrategy {\n      verifyOldEmail\n    }\n    qrcodeLoginStrategy {\n      qrcodeExpiresAfter\n      returnFullUserInfo\n      allowExchangeUserInfoFromBrowser\n      ticketExpiresAfter\n    }\n    app2WxappLoginStrategy {\n      ticketExpriresAfter\n      ticketExchangeUserInfoNeedSecret\n    }\n    whitelist {\n      phoneEnabled\n      emailEnabled\n      usernameEnabled\n    }\n    customSMSProvider {\n      enabled\n      provider\n    }\n    packageType\n  }\n}\n    ";
export declare const DeleteFunctionDocument = "\n    mutation deleteFunction($id: String!) {\n  deleteFunction(id: $id) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteGroupsDocument = "\n    mutation deleteGroups($codeList: [String!]!) {\n  deleteGroups(codeList: $codeList) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteNodeDocument = "\n    mutation deleteNode($orgId: String!, $nodeId: String!) {\n  deleteNode(orgId: $orgId, nodeId: $nodeId) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteOrgDocument = "\n    mutation deleteOrg($id: String!) {\n  deleteOrg(id: $id) {\n    message\n    code\n  }\n}\n    ";
export declare const DeletePoliciesDocument = "\n    mutation deletePolicies($codeList: [String!]!, $namespace: String) {\n  deletePolicies(codeList: $codeList, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const DeletePolicyDocument = "\n    mutation deletePolicy($code: String!, $namespace: String) {\n  deletePolicy(code: $code, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteRoleDocument = "\n    mutation deleteRole($code: String!, $namespace: String) {\n  deleteRole(code: $code, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteRolesDocument = "\n    mutation deleteRoles($codeList: [String!]!, $namespace: String) {\n  deleteRoles(codeList: $codeList, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteUserDocument = "\n    mutation deleteUser($id: String!) {\n  deleteUser(id: $id) {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteUserpoolDocument = "\n    mutation deleteUserpool {\n  deleteUserpool {\n    message\n    code\n  }\n}\n    ";
export declare const DeleteUsersDocument = "\n    mutation deleteUsers($ids: [String!]!) {\n  deleteUsers(ids: $ids) {\n    message\n    code\n  }\n}\n    ";
export declare const DisableEmailTemplateDocument = "\n    mutation disableEmailTemplate($type: EmailTemplateType!) {\n  disableEmailTemplate(type: $type) {\n    type\n    name\n    subject\n    sender\n    content\n    redirectTo\n    hasURL\n    expiresIn\n    enabled\n    isSystem\n  }\n}\n    ";
export declare const DisableSocialConnectionInstanceDocument = "\n    mutation disableSocialConnectionInstance($provider: String!) {\n  disableSocialConnectionInstance(provider: $provider) {\n    provider\n    enabled\n    fields {\n      key\n      value\n    }\n  }\n}\n    ";
export declare const DisbalePolicyAssignmentDocument = "\n    mutation disbalePolicyAssignment($policy: String!, $targetType: PolicyAssignmentTargetType!, $targetIdentifier: String!, $namespace: String) {\n  disbalePolicyAssignment(policy: $policy, targetType: $targetType, targetIdentifier: $targetIdentifier, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const EnableEmailTemplateDocument = "\n    mutation enableEmailTemplate($type: EmailTemplateType!) {\n  enableEmailTemplate(type: $type) {\n    type\n    name\n    subject\n    sender\n    content\n    redirectTo\n    hasURL\n    expiresIn\n    enabled\n    isSystem\n  }\n}\n    ";
export declare const EnablePolicyAssignmentDocument = "\n    mutation enablePolicyAssignment($policy: String!, $targetType: PolicyAssignmentTargetType!, $targetIdentifier: String!, $namespace: String) {\n  enablePolicyAssignment(policy: $policy, targetType: $targetType, targetIdentifier: $targetIdentifier, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const EnableSocialConnectionInstanceDocument = "\n    mutation enableSocialConnectionInstance($provider: String!) {\n  enableSocialConnectionInstance(provider: $provider) {\n    provider\n    enabled\n    fields {\n      key\n      value\n    }\n  }\n}\n    ";
export declare const LoginByEmailDocument = "\n    mutation loginByEmail($input: LoginByEmailInput!) {\n  loginByEmail(input: $input) {\n    id\n    arn\n    status\n    userPoolId\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const LoginByPhoneCodeDocument = "\n    mutation loginByPhoneCode($input: LoginByPhoneCodeInput!) {\n  loginByPhoneCode(input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const LoginByPhonePasswordDocument = "\n    mutation loginByPhonePassword($input: LoginByPhonePasswordInput!) {\n  loginByPhonePassword(input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const LoginBySubAccountDocument = "\n    mutation loginBySubAccount($account: String!, $password: String!, $captchaCode: String, $clientIp: String) {\n  loginBySubAccount(account: $account, password: $password, captchaCode: $captchaCode, clientIp: $clientIp) {\n    id\n    arn\n    status\n    userPoolId\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const LoginByUsernameDocument = "\n    mutation loginByUsername($input: LoginByUsernameInput!) {\n  loginByUsername(input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const MoveNodeDocument = "\n    mutation moveNode($orgId: String!, $nodeId: String!, $targetParentId: String!) {\n  moveNode(orgId: $orgId, nodeId: $nodeId, targetParentId: $targetParentId) {\n    id\n    rootNode {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n    nodes {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n  }\n}\n    ";
export declare const RefreshAccessTokenDocument = "\n    mutation refreshAccessToken($accessToken: String) {\n  refreshAccessToken(accessToken: $accessToken) {\n    accessToken\n    exp\n    iat\n  }\n}\n    ";
export declare const RefreshTokenDocument = "\n    mutation refreshToken($id: String) {\n  refreshToken(id: $id) {\n    token\n    iat\n    exp\n  }\n}\n    ";
export declare const RefreshUserpoolSecretDocument = "\n    mutation refreshUserpoolSecret {\n  refreshUserpoolSecret\n}\n    ";
export declare const RegisterByEmailDocument = "\n    mutation registerByEmail($input: RegisterByEmailInput!) {\n  registerByEmail(input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const RegisterByPhoneCodeDocument = "\n    mutation registerByPhoneCode($input: RegisterByPhoneCodeInput!) {\n  registerByPhoneCode(input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const RegisterByUsernameDocument = "\n    mutation registerByUsername($input: RegisterByUsernameInput!) {\n  registerByUsername(input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const RemoveMemberDocument = "\n    mutation removeMember($page: Int, $limit: Int, $sortBy: SortByEnum, $includeChildrenNodes: Boolean, $nodeId: String, $orgId: String, $nodeCode: String, $userIds: [String!]!) {\n  removeMember(nodeId: $nodeId, orgId: $orgId, nodeCode: $nodeCode, userIds: $userIds) {\n    id\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    createdAt\n    updatedAt\n    children\n    users(page: $page, limit: $limit, sortBy: $sortBy, includeChildrenNodes: $includeChildrenNodes) {\n      totalCount\n      list {\n        id\n        arn\n        userPoolId\n        status\n        username\n        email\n        emailVerified\n        phone\n        phoneVerified\n        unionid\n        openid\n        nickname\n        registerSource\n        photo\n        password\n        oauth\n        token\n        tokenExpiredAt\n        loginsCount\n        lastLogin\n        lastIP\n        signedUp\n        blocked\n        isDeleted\n        device\n        browser\n        company\n        name\n        givenName\n        familyName\n        middleName\n        profile\n        preferredUsername\n        website\n        gender\n        birthdate\n        zoneinfo\n        locale\n        address\n        formatted\n        streetAddress\n        locality\n        region\n        postalCode\n        city\n        province\n        country\n        createdAt\n        updatedAt\n      }\n    }\n  }\n}\n    ";
export declare const RemovePolicyAssignmentsDocument = "\n    mutation removePolicyAssignments($policies: [String!]!, $targetType: PolicyAssignmentTargetType!, $targetIdentifiers: [String!], $namespace: String) {\n  removePolicyAssignments(policies: $policies, targetType: $targetType, targetIdentifiers: $targetIdentifiers, namespace: $namespace) {\n    message\n    code\n  }\n}\n    ";
export declare const RemoveUdfDocument = "\n    mutation removeUdf($targetType: UDFTargetType!, $key: String!) {\n  removeUdf(targetType: $targetType, key: $key) {\n    message\n    code\n  }\n}\n    ";
export declare const RemoveUdvDocument = "\n    mutation removeUdv($targetType: UDFTargetType!, $targetId: String!, $key: String!) {\n  removeUdv(targetType: $targetType, targetId: $targetId, key: $key) {\n    key\n    dataType\n    value\n    label\n  }\n}\n    ";
export declare const RemoveUserFromGroupDocument = "\n    mutation removeUserFromGroup($userIds: [String!]!, $code: String) {\n  removeUserFromGroup(userIds: $userIds, code: $code) {\n    message\n    code\n  }\n}\n    ";
export declare const RemoveWhitelistDocument = "\n    mutation removeWhitelist($type: WhitelistType!, $list: [String!]!) {\n  removeWhitelist(type: $type, list: $list) {\n    createdAt\n    updatedAt\n    value\n  }\n}\n    ";
export declare const ResetPasswordDocument = "\n    mutation resetPassword($phone: String, $email: String, $code: String!, $newPassword: String!) {\n  resetPassword(phone: $phone, email: $email, code: $code, newPassword: $newPassword) {\n    message\n    code\n  }\n}\n    ";
export declare const RevokeRoleDocument = "\n    mutation revokeRole($namespace: String, $roleCode: String, $roleCodes: [String], $userIds: [String!], $groupCodes: [String!], $nodeCodes: [String!]) {\n  revokeRole(namespace: $namespace, roleCode: $roleCode, roleCodes: $roleCodes, userIds: $userIds, groupCodes: $groupCodes, nodeCodes: $nodeCodes) {\n    message\n    code\n  }\n}\n    ";
export declare const SendEmailDocument = "\n    mutation sendEmail($email: String!, $scene: EmailScene!) {\n  sendEmail(email: $email, scene: $scene) {\n    message\n    code\n  }\n}\n    ";
export declare const SetMainDepartmentDocument = "\n    mutation setMainDepartment($userId: String!, $departmentId: String) {\n  setMainDepartment(userId: $userId, departmentId: $departmentId) {\n    message\n    code\n  }\n}\n    ";
export declare const SetUdfDocument = "\n    mutation setUdf($targetType: UDFTargetType!, $key: String!, $dataType: UDFDataType!, $label: String!, $options: String) {\n  setUdf(targetType: $targetType, key: $key, dataType: $dataType, label: $label, options: $options) {\n    targetType\n    dataType\n    key\n    label\n    options\n  }\n}\n    ";
export declare const SetUdfValueBatchDocument = "\n    mutation setUdfValueBatch($targetType: UDFTargetType!, $input: [SetUdfValueBatchInput!]!) {\n  setUdfValueBatch(targetType: $targetType, input: $input) {\n    code\n    message\n  }\n}\n    ";
export declare const SetUdvDocument = "\n    mutation setUdv($targetType: UDFTargetType!, $targetId: String!, $key: String!, $value: String!) {\n  setUdv(targetType: $targetType, targetId: $targetId, key: $key, value: $value) {\n    key\n    dataType\n    value\n    label\n  }\n}\n    ";
export declare const SetUdvBatchDocument = "\n    mutation setUdvBatch($targetType: UDFTargetType!, $targetId: String!, $udvList: [UserDefinedDataInput!]) {\n  setUdvBatch(targetType: $targetType, targetId: $targetId, udvList: $udvList) {\n    key\n    dataType\n    value\n    label\n  }\n}\n    ";
export declare const UnbindEmailDocument = "\n    mutation unbindEmail {\n  unbindEmail {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UnbindPhoneDocument = "\n    mutation unbindPhone {\n  unbindPhone {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UpdateEmailDocument = "\n    mutation updateEmail($email: String!, $emailCode: String!, $oldEmail: String, $oldEmailCode: String) {\n  updateEmail(email: $email, emailCode: $emailCode, oldEmail: $oldEmail, oldEmailCode: $oldEmailCode) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UpdateFunctionDocument = "\n    mutation updateFunction($input: UpdateFunctionInput!) {\n  updateFunction(input: $input) {\n    id\n    name\n    sourceCode\n    description\n    url\n  }\n}\n    ";
export declare const UpdateGroupDocument = "\n    mutation updateGroup($code: String!, $name: String, $description: String, $newCode: String) {\n  updateGroup(code: $code, name: $name, description: $description, newCode: $newCode) {\n    code\n    name\n    description\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UpdateNodeDocument = "\n    mutation updateNode($page: Int, $limit: Int, $sortBy: SortByEnum, $includeChildrenNodes: Boolean, $id: String!, $name: String, $code: String, $description: String) {\n  updateNode(id: $id, name: $name, code: $code, description: $description) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    createdAt\n    updatedAt\n    children\n    users(page: $page, limit: $limit, sortBy: $sortBy, includeChildrenNodes: $includeChildrenNodes) {\n      totalCount\n    }\n  }\n}\n    ";
export declare const UpdatePasswordDocument = "\n    mutation updatePassword($newPassword: String!, $oldPassword: String) {\n  updatePassword(newPassword: $newPassword, oldPassword: $oldPassword) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UpdatePhoneDocument = "\n    mutation updatePhone($phone: String!, $phoneCode: String!, $oldPhone: String, $oldPhoneCode: String) {\n  updatePhone(phone: $phone, phoneCode: $phoneCode, oldPhone: $oldPhone, oldPhoneCode: $oldPhoneCode) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UpdatePolicyDocument = "\n    mutation updatePolicy($namespace: String, $code: String!, $description: String, $statements: [PolicyStatementInput!], $newCode: String) {\n  updatePolicy(namespace: $namespace, code: $code, description: $description, statements: $statements, newCode: $newCode) {\n    namespace\n    code\n    description\n    statements {\n      resource\n      actions\n      effect\n      condition {\n        param\n        operator\n        value\n      }\n    }\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const UpdateRoleDocument = "\n    mutation updateRole($code: String!, $description: String, $newCode: String, $namespace: String) {\n  updateRole(code: $code, description: $description, newCode: $newCode, namespace: $namespace) {\n    namespace\n    code\n    arn\n    description\n    createdAt\n    updatedAt\n    parent {\n      namespace\n      code\n      arn\n      description\n      createdAt\n      updatedAt\n    }\n  }\n}\n    ";
export declare const UpdateUserDocument = "\n    mutation updateUser($id: String, $input: UpdateUserInput!) {\n  updateUser(id: $id, input: $input) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const UpdateUserpoolDocument = "\n    mutation updateUserpool($input: UpdateUserpoolInput!) {\n  updateUserpool(input: $input) {\n    id\n    name\n    domain\n    description\n    secret\n    jwtSecret\n    userpoolTypes {\n      code\n      name\n      description\n      image\n      sdks\n    }\n    logo\n    createdAt\n    updatedAt\n    emailVerifiedDefault\n    sendWelcomeEmail\n    registerDisabled\n    appSsoEnabled\n    showWxQRCodeWhenRegisterDisabled\n    allowedOrigins\n    tokenExpiresAfter\n    isDeleted\n    frequentRegisterCheck {\n      timeInterval\n      limit\n      enabled\n    }\n    loginFailCheck {\n      timeInterval\n      limit\n      enabled\n    }\n    changePhoneStrategy {\n      verifyOldPhone\n    }\n    changeEmailStrategy {\n      verifyOldEmail\n    }\n    qrcodeLoginStrategy {\n      qrcodeExpiresAfter\n      returnFullUserInfo\n      allowExchangeUserInfoFromBrowser\n      ticketExpiresAfter\n    }\n    app2WxappLoginStrategy {\n      ticketExpriresAfter\n      ticketExchangeUserInfoNeedSecret\n    }\n    whitelist {\n      phoneEnabled\n      emailEnabled\n      usernameEnabled\n    }\n    customSMSProvider {\n      enabled\n      provider\n      config\n    }\n    packageType\n    useCustomUserStore\n    loginRequireEmailVerified\n    verifyCodeLength\n  }\n}\n    ";
export declare const AccessTokenDocument = "\n    query accessToken($userPoolId: String!, $secret: String!) {\n  accessToken(userPoolId: $userPoolId, secret: $secret) {\n    accessToken\n    exp\n    iat\n  }\n}\n    ";
export declare const ArchivedUsersDocument = "\n    query archivedUsers($page: Int, $limit: Int) {\n  archivedUsers(page: $page, limit: $limit) {\n    totalCount\n    list {\n      id\n      arn\n      status\n      userPoolId\n      username\n      email\n      emailVerified\n      phone\n      phoneVerified\n      unionid\n      openid\n      nickname\n      registerSource\n      photo\n      password\n      oauth\n      token\n      tokenExpiredAt\n      loginsCount\n      lastLogin\n      lastIP\n      signedUp\n      blocked\n      isDeleted\n      device\n      browser\n      company\n      name\n      givenName\n      familyName\n      middleName\n      profile\n      preferredUsername\n      website\n      gender\n      birthdate\n      zoneinfo\n      locale\n      address\n      formatted\n      streetAddress\n      locality\n      region\n      postalCode\n      city\n      province\n      country\n      createdAt\n      updatedAt\n      externalId\n    }\n  }\n}\n    ";
export declare const AuthorizedTargetsDocument = "\n    query authorizedTargets($namespace: String!, $resourceType: ResourceType!, $resource: String!, $targetType: PolicyAssignmentTargetType, $actions: AuthorizedTargetsActionsInput) {\n  authorizedTargets(namespace: $namespace, resource: $resource, resourceType: $resourceType, targetType: $targetType, actions: $actions) {\n    totalCount\n    list {\n      targetType\n      targetIdentifier\n      actions\n    }\n  }\n}\n    ";
export declare const CheckLoginStatusDocument = "\n    query checkLoginStatus($token: String) {\n  checkLoginStatus(token: $token) {\n    code\n    message\n    status\n    exp\n    iat\n    data {\n      id\n      userPoolId\n      arn\n    }\n  }\n}\n    ";
export declare const CheckPasswordStrengthDocument = "\n    query checkPasswordStrength($password: String!) {\n  checkPasswordStrength(password: $password) {\n    valid\n    message\n  }\n}\n    ";
export declare const ChildrenNodesDocument = "\n    query childrenNodes($orgId: String!, $nodeId: String!) {\n  childrenNodes(orgId: $orgId, nodeId: $nodeId) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    createdAt\n    updatedAt\n    children\n  }\n}\n    ";
export declare const EmailTemplatesDocument = "\n    query emailTemplates {\n  emailTemplates {\n    type\n    name\n    subject\n    sender\n    content\n    redirectTo\n    hasURL\n    expiresIn\n    enabled\n    isSystem\n  }\n}\n    ";
export declare const FindUserDocument = "\n    query findUser($email: String, $phone: String, $username: String, $externalId: String) {\n  findUser(email: $email, phone: $phone, username: $username, externalId: $externalId) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const FunctionDocument = "\n    query function($id: String) {\n  function(id: $id) {\n    id\n    name\n    sourceCode\n    description\n    url\n  }\n}\n    ";
export declare const FunctionsDocument = "\n    query functions($page: Int, $limit: Int, $sortBy: SortByEnum) {\n  functions(page: $page, limit: $limit, sortBy: $sortBy) {\n    list {\n      id\n      name\n      sourceCode\n      description\n      url\n    }\n    totalCount\n  }\n}\n    ";
export declare const GetUserDepartmentsDocument = "\n    query getUserDepartments($id: String!, $orgId: String) {\n  user(id: $id) {\n    departments(orgId: $orgId) {\n      totalCount\n      list {\n        department {\n          id\n          orgId\n          name\n          nameI18n\n          description\n          descriptionI18n\n          order\n          code\n          root\n          depth\n          path\n          codePath\n          namePath\n          createdAt\n          updatedAt\n          children\n        }\n        isMainDepartment\n        joinedAt\n      }\n    }\n  }\n}\n    ";
export declare const GetUserGroupsDocument = "\n    query getUserGroups($id: String!) {\n  user(id: $id) {\n    groups {\n      totalCount\n      list {\n        code\n        name\n        description\n        createdAt\n        updatedAt\n      }\n    }\n  }\n}\n    ";
export declare const GetUserRolesDocument = "\n    query getUserRoles($id: String!, $namespace: String) {\n  user(id: $id) {\n    roles(namespace: $namespace) {\n      totalCount\n      list {\n        code\n        namespace\n        arn\n        description\n        createdAt\n        updatedAt\n        parent {\n          code\n          namespace\n          arn\n          description\n          createdAt\n          updatedAt\n        }\n      }\n    }\n  }\n}\n    ";
export declare const GroupDocument = "\n    query group($code: String!) {\n  group(code: $code) {\n    code\n    name\n    description\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const GroupWithUsersDocument = "\n    query groupWithUsers($code: String!, $page: Int, $limit: Int) {\n  group(code: $code) {\n    users(page: $page, limit: $limit) {\n      totalCount\n      list {\n        id\n        arn\n        userPoolId\n        username\n        email\n        emailVerified\n        phone\n        phoneVerified\n        unionid\n        openid\n        nickname\n        registerSource\n        photo\n        password\n        oauth\n        token\n        tokenExpiredAt\n        loginsCount\n        lastLogin\n        lastIP\n        signedUp\n        blocked\n        isDeleted\n        device\n        browser\n        company\n        name\n        givenName\n        familyName\n        middleName\n        profile\n        preferredUsername\n        website\n        gender\n        birthdate\n        zoneinfo\n        locale\n        address\n        formatted\n        streetAddress\n        locality\n        region\n        postalCode\n        city\n        province\n        country\n        createdAt\n        updatedAt\n        externalId\n      }\n    }\n  }\n}\n    ";
export declare const GroupsDocument = "\n    query groups($userId: String, $page: Int, $limit: Int, $sortBy: SortByEnum) {\n  groups(userId: $userId, page: $page, limit: $limit, sortBy: $sortBy) {\n    totalCount\n    list {\n      code\n      name\n      description\n      createdAt\n      updatedAt\n    }\n  }\n}\n    ";
export declare const IsActionAllowedDocument = "\n    query isActionAllowed($resource: String!, $action: String!, $userId: String!, $namespace: String) {\n  isActionAllowed(resource: $resource, action: $action, userId: $userId, namespace: $namespace)\n}\n    ";
export declare const IsActionDeniedDocument = "\n    query isActionDenied($resource: String!, $action: String!, $userId: String!, $namespace: String) {\n  isActionDenied(resource: $resource, action: $action, userId: $userId, namespace: $namespace)\n}\n    ";
export declare const IsDomainAvaliableDocument = "\n    query isDomainAvaliable($domain: String!) {\n  isDomainAvaliable(domain: $domain)\n}\n    ";
export declare const IsRootNodeDocument = "\n    query isRootNode($nodeId: String!, $orgId: String!) {\n  isRootNode(nodeId: $nodeId, orgId: $orgId)\n}\n    ";
export declare const IsUserExistsDocument = "\n    query isUserExists($email: String, $phone: String, $username: String, $externalId: String) {\n  isUserExists(email: $email, phone: $phone, username: $username, externalId: $externalId)\n}\n    ";
export declare const AuthorizedResourcesDocument = "\n    query authorizedResources($targetType: PolicyAssignmentTargetType, $targetIdentifier: String, $namespace: String, $resourceType: String) {\n  authorizedResources(targetType: $targetType, targetIdentifier: $targetIdentifier, namespace: $namespace, resourceType: $resourceType) {\n    totalCount\n    list {\n      code\n      type\n      actions\n    }\n  }\n}\n    ";
export declare const ListGroupAuthorizedResourcesDocument = "\n    query listGroupAuthorizedResources($code: String!, $namespace: String, $resourceType: String) {\n  group(code: $code) {\n    authorizedResources(namespace: $namespace, resourceType: $resourceType) {\n      totalCount\n      list {\n        code\n        type\n        actions\n      }\n    }\n  }\n}\n    ";
export declare const ListNodeByCodeAuthorizedResourcesDocument = "\n    query listNodeByCodeAuthorizedResources($orgId: String!, $code: String!, $namespace: String, $resourceType: String) {\n  nodeByCode(orgId: $orgId, code: $code) {\n    authorizedResources(namespace: $namespace, resourceType: $resourceType) {\n      totalCount\n      list {\n        code\n        type\n        actions\n      }\n    }\n  }\n}\n    ";
export declare const ListNodeByIdAuthorizedResourcesDocument = "\n    query listNodeByIdAuthorizedResources($id: String!, $namespace: String, $resourceType: String) {\n  nodeById(id: $id) {\n    authorizedResources(namespace: $namespace, resourceType: $resourceType) {\n      totalCount\n      list {\n        code\n        type\n        actions\n      }\n    }\n  }\n}\n    ";
export declare const ListRoleAuthorizedResourcesDocument = "\n    query listRoleAuthorizedResources($code: String!, $namespace: String, $resourceType: String) {\n  role(code: $code, namespace: $namespace) {\n    authorizedResources(resourceType: $resourceType) {\n      totalCount\n      list {\n        code\n        type\n        actions\n      }\n    }\n  }\n}\n    ";
export declare const ListUserAuthorizedResourcesDocument = "\n    query listUserAuthorizedResources($id: String!, $namespace: String, $resourceType: String) {\n  user(id: $id) {\n    authorizedResources(namespace: $namespace, resourceType: $resourceType) {\n      totalCount\n      list {\n        code\n        type\n        actions\n      }\n    }\n  }\n}\n    ";
export declare const NodeByCodeDocument = "\n    query nodeByCode($orgId: String!, $code: String!) {\n  nodeByCode(orgId: $orgId, code: $code) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    createdAt\n    updatedAt\n    children\n  }\n}\n    ";
export declare const NodeByCodeWithMembersDocument = "\n    query nodeByCodeWithMembers($page: Int, $limit: Int, $sortBy: SortByEnum, $includeChildrenNodes: Boolean, $orgId: String!, $code: String!) {\n  nodeByCode(orgId: $orgId, code: $code) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    createdAt\n    updatedAt\n    children\n    users(page: $page, limit: $limit, sortBy: $sortBy, includeChildrenNodes: $includeChildrenNodes) {\n      totalCount\n      list {\n        id\n        arn\n        userPoolId\n        status\n        username\n        email\n        emailVerified\n        phone\n        phoneVerified\n        unionid\n        openid\n        nickname\n        registerSource\n        photo\n        password\n        oauth\n        token\n        tokenExpiredAt\n        loginsCount\n        lastLogin\n        lastIP\n        signedUp\n        blocked\n        isDeleted\n        device\n        browser\n        company\n        name\n        givenName\n        familyName\n        middleName\n        profile\n        preferredUsername\n        website\n        gender\n        birthdate\n        zoneinfo\n        locale\n        address\n        formatted\n        streetAddress\n        locality\n        region\n        postalCode\n        city\n        province\n        country\n        createdAt\n        updatedAt\n        externalId\n      }\n    }\n  }\n}\n    ";
export declare const NodeByIdDocument = "\n    query nodeById($id: String!) {\n  nodeById(id: $id) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    createdAt\n    updatedAt\n    children\n  }\n}\n    ";
export declare const NodeByIdWithMembersDocument = "\n    query nodeByIdWithMembers($page: Int, $limit: Int, $sortBy: SortByEnum, $includeChildrenNodes: Boolean, $id: String!) {\n  nodeById(id: $id) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    createdAt\n    updatedAt\n    children\n    users(page: $page, limit: $limit, sortBy: $sortBy, includeChildrenNodes: $includeChildrenNodes) {\n      totalCount\n      list {\n        id\n        arn\n        userPoolId\n        status\n        username\n        email\n        emailVerified\n        phone\n        phoneVerified\n        unionid\n        openid\n        nickname\n        registerSource\n        photo\n        password\n        oauth\n        token\n        tokenExpiredAt\n        loginsCount\n        lastLogin\n        lastIP\n        signedUp\n        blocked\n        isDeleted\n        device\n        browser\n        company\n        name\n        givenName\n        familyName\n        middleName\n        profile\n        preferredUsername\n        website\n        gender\n        birthdate\n        zoneinfo\n        locale\n        address\n        formatted\n        streetAddress\n        locality\n        region\n        postalCode\n        city\n        province\n        country\n        createdAt\n        updatedAt\n        externalId\n      }\n    }\n  }\n}\n    ";
export declare const OrgDocument = "\n    query org($id: String!) {\n  org(id: $id) {\n    id\n    rootNode {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n    nodes {\n      id\n      orgId\n      name\n      nameI18n\n      description\n      descriptionI18n\n      order\n      code\n      root\n      depth\n      path\n      createdAt\n      updatedAt\n      children\n    }\n  }\n}\n    ";
export declare const OrgsDocument = "\n    query orgs($page: Int, $limit: Int, $sortBy: SortByEnum) {\n  orgs(page: $page, limit: $limit, sortBy: $sortBy) {\n    totalCount\n    list {\n      id\n      rootNode {\n        id\n        name\n        nameI18n\n        path\n        description\n        descriptionI18n\n        order\n        code\n        root\n        depth\n        createdAt\n        updatedAt\n        children\n      }\n      nodes {\n        id\n        name\n        path\n        nameI18n\n        description\n        descriptionI18n\n        order\n        code\n        root\n        depth\n        createdAt\n        updatedAt\n        children\n      }\n    }\n  }\n}\n    ";
export declare const PoliciesDocument = "\n    query policies($page: Int, $limit: Int, $namespace: String) {\n  policies(page: $page, limit: $limit, namespace: $namespace) {\n    totalCount\n    list {\n      namespace\n      code\n      description\n      createdAt\n      updatedAt\n      statements {\n        resource\n        actions\n        effect\n        condition {\n          param\n          operator\n          value\n        }\n      }\n    }\n  }\n}\n    ";
export declare const PolicyDocument = "\n    query policy($namespace: String, $code: String!) {\n  policy(code: $code, namespace: $namespace) {\n    namespace\n    code\n    isDefault\n    description\n    statements {\n      resource\n      actions\n      effect\n      condition {\n        param\n        operator\n        value\n      }\n    }\n    createdAt\n    updatedAt\n  }\n}\n    ";
export declare const PolicyAssignmentsDocument = "\n    query policyAssignments($namespace: String, $code: String, $targetType: PolicyAssignmentTargetType, $targetIdentifier: String, $page: Int, $limit: Int) {\n  policyAssignments(namespace: $namespace, code: $code, targetType: $targetType, targetIdentifier: $targetIdentifier, page: $page, limit: $limit) {\n    totalCount\n    list {\n      code\n      targetType\n      targetIdentifier\n    }\n  }\n}\n    ";
export declare const PolicyWithAssignmentsDocument = "\n    query policyWithAssignments($page: Int, $limit: Int, $code: String!) {\n  policy(code: $code) {\n    code\n    isDefault\n    description\n    statements {\n      resource\n      actions\n      effect\n    }\n    createdAt\n    updatedAt\n    assignmentsCount\n    assignments(page: $page, limit: $limit) {\n      code\n      targetType\n      targetIdentifier\n    }\n  }\n}\n    ";
export declare const PreviewEmailDocument = "\n    query previewEmail($type: EmailTemplateType!) {\n  previewEmail(type: $type)\n}\n    ";
export declare const QiniuUptokenDocument = "\n    query qiniuUptoken($type: String) {\n  qiniuUptoken(type: $type)\n}\n    ";
export declare const QueryMfaDocument = "\n    query queryMfa($id: String, $userId: String, $userPoolId: String) {\n  queryMfa(id: $id, userId: $userId, userPoolId: $userPoolId) {\n    id\n    userId\n    userPoolId\n    enable\n    secret\n  }\n}\n    ";
export declare const RoleDocument = "\n    query role($code: String!, $namespace: String) {\n  role(code: $code, namespace: $namespace) {\n    namespace\n    code\n    arn\n    description\n    createdAt\n    updatedAt\n    parent {\n      namespace\n      code\n      arn\n      description\n      createdAt\n      updatedAt\n    }\n  }\n}\n    ";
export declare const RoleWithUsersDocument = "\n    query roleWithUsers($code: String!, $namespace: String) {\n  role(code: $code, namespace: $namespace) {\n    users {\n      totalCount\n      list {\n        id\n        arn\n        status\n        userPoolId\n        username\n        email\n        emailVerified\n        phone\n        phoneVerified\n        unionid\n        openid\n        nickname\n        registerSource\n        photo\n        password\n        oauth\n        token\n        tokenExpiredAt\n        loginsCount\n        lastLogin\n        lastIP\n        signedUp\n        blocked\n        isDeleted\n        device\n        browser\n        company\n        name\n        givenName\n        familyName\n        middleName\n        profile\n        preferredUsername\n        website\n        gender\n        birthdate\n        zoneinfo\n        locale\n        address\n        formatted\n        streetAddress\n        locality\n        region\n        postalCode\n        city\n        province\n        country\n        createdAt\n        updatedAt\n        externalId\n      }\n    }\n  }\n}\n    ";
export declare const RolesDocument = "\n    query roles($namespace: String, $page: Int, $limit: Int, $sortBy: SortByEnum) {\n  roles(namespace: $namespace, page: $page, limit: $limit, sortBy: $sortBy) {\n    totalCount\n    list {\n      namespace\n      code\n      arn\n      description\n      createdAt\n      updatedAt\n    }\n  }\n}\n    ";
export declare const RootNodeDocument = "\n    query rootNode($orgId: String!) {\n  rootNode(orgId: $orgId) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    codePath\n    namePath\n    createdAt\n    updatedAt\n    children\n  }\n}\n    ";
export declare const SearchNodesDocument = "\n    query searchNodes($keyword: String!) {\n  searchNodes(keyword: $keyword) {\n    id\n    orgId\n    name\n    nameI18n\n    description\n    descriptionI18n\n    order\n    code\n    root\n    depth\n    path\n    codePath\n    namePath\n    createdAt\n    updatedAt\n    children\n  }\n}\n    ";
export declare const SearchUserDocument = "\n    query searchUser($query: String!, $fields: [String], $page: Int, $limit: Int, $departmentOpts: [SearchUserDepartmentOpt], $groupOpts: [SearchUserGroupOpt], $roleOpts: [SearchUserRoleOpt]) {\n  searchUser(query: $query, fields: $fields, page: $page, limit: $limit, departmentOpts: $departmentOpts, groupOpts: $groupOpts, roleOpts: $roleOpts) {\n    totalCount\n    list {\n      id\n      arn\n      userPoolId\n      status\n      username\n      email\n      emailVerified\n      phone\n      phoneVerified\n      unionid\n      openid\n      nickname\n      registerSource\n      photo\n      password\n      oauth\n      token\n      tokenExpiredAt\n      loginsCount\n      lastLogin\n      lastIP\n      signedUp\n      blocked\n      isDeleted\n      device\n      browser\n      company\n      name\n      givenName\n      familyName\n      middleName\n      profile\n      preferredUsername\n      website\n      gender\n      birthdate\n      zoneinfo\n      locale\n      address\n      formatted\n      streetAddress\n      locality\n      region\n      postalCode\n      city\n      province\n      country\n      createdAt\n      updatedAt\n      externalId\n    }\n  }\n}\n    ";
export declare const SocialConnectionDocument = "\n    query socialConnection($provider: String!) {\n  socialConnection(provider: $provider) {\n    provider\n    name\n    logo\n    description\n    fields {\n      key\n      label\n      type\n      placeholder\n    }\n  }\n}\n    ";
export declare const SocialConnectionInstanceDocument = "\n    query socialConnectionInstance($provider: String!) {\n  socialConnectionInstance(provider: $provider) {\n    provider\n    enabled\n    fields {\n      key\n      value\n    }\n  }\n}\n    ";
export declare const SocialConnectionInstancesDocument = "\n    query socialConnectionInstances {\n  socialConnectionInstances {\n    provider\n    enabled\n    fields {\n      key\n      value\n    }\n  }\n}\n    ";
export declare const SocialConnectionsDocument = "\n    query socialConnections {\n  socialConnections {\n    provider\n    name\n    logo\n    description\n    fields {\n      key\n      label\n      type\n      placeholder\n    }\n  }\n}\n    ";
export declare const TemplateCodeDocument = "\n    query templateCode {\n  templateCode\n}\n    ";
export declare const UdfDocument = "\n    query udf($targetType: UDFTargetType!) {\n  udf(targetType: $targetType) {\n    targetType\n    dataType\n    key\n    label\n    options\n  }\n}\n    ";
export declare const UdfValueBatchDocument = "\n    query udfValueBatch($targetType: UDFTargetType!, $targetIds: [String!]!) {\n  udfValueBatch(targetType: $targetType, targetIds: $targetIds) {\n    targetId\n    data {\n      key\n      dataType\n      value\n      label\n    }\n  }\n}\n    ";
export declare const UdvDocument = "\n    query udv($targetType: UDFTargetType!, $targetId: String!) {\n  udv(targetType: $targetType, targetId: $targetId) {\n    key\n    dataType\n    value\n    label\n  }\n}\n    ";
export declare const UserDocument = "\n    query user($id: String) {\n  user(id: $id) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    identities {\n      openid\n      userIdInIdp\n      userId\n      connectionId\n      isSocial\n      provider\n      userPoolId\n    }\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const UserBatchDocument = "\n    query userBatch($ids: [String!]!) {\n  userBatch(ids: $ids) {\n    id\n    arn\n    userPoolId\n    status\n    username\n    email\n    emailVerified\n    phone\n    phoneVerified\n    unionid\n    openid\n    nickname\n    registerSource\n    photo\n    password\n    oauth\n    token\n    tokenExpiredAt\n    loginsCount\n    lastLogin\n    lastIP\n    signedUp\n    blocked\n    isDeleted\n    device\n    browser\n    company\n    name\n    givenName\n    familyName\n    middleName\n    profile\n    preferredUsername\n    website\n    gender\n    birthdate\n    zoneinfo\n    locale\n    address\n    formatted\n    streetAddress\n    locality\n    region\n    postalCode\n    city\n    province\n    country\n    createdAt\n    updatedAt\n    externalId\n  }\n}\n    ";
export declare const UserpoolDocument = "\n    query userpool {\n  userpool {\n    id\n    name\n    domain\n    description\n    secret\n    jwtSecret\n    ownerId\n    userpoolTypes {\n      code\n      name\n      description\n      image\n      sdks\n    }\n    logo\n    createdAt\n    updatedAt\n    emailVerifiedDefault\n    sendWelcomeEmail\n    registerDisabled\n    appSsoEnabled\n    showWxQRCodeWhenRegisterDisabled\n    allowedOrigins\n    tokenExpiresAfter\n    isDeleted\n    frequentRegisterCheck {\n      timeInterval\n      limit\n      enabled\n    }\n    loginFailCheck {\n      timeInterval\n      limit\n      enabled\n    }\n    changePhoneStrategy {\n      verifyOldPhone\n    }\n    changeEmailStrategy {\n      verifyOldEmail\n    }\n    qrcodeLoginStrategy {\n      qrcodeExpiresAfter\n      returnFullUserInfo\n      allowExchangeUserInfoFromBrowser\n      ticketExpiresAfter\n    }\n    app2WxappLoginStrategy {\n      ticketExpriresAfter\n      ticketExchangeUserInfoNeedSecret\n    }\n    whitelist {\n      phoneEnabled\n      emailEnabled\n      usernameEnabled\n    }\n    customSMSProvider {\n      enabled\n      provider\n      config\n    }\n    packageType\n    useCustomUserStore\n    loginRequireEmailVerified\n    verifyCodeLength\n  }\n}\n    ";
export declare const UserpoolTypesDocument = "\n    query userpoolTypes {\n  userpoolTypes {\n    code\n    name\n    description\n    image\n    sdks\n  }\n}\n    ";
export declare const UserpoolsDocument = "\n    query userpools($page: Int, $limit: Int, $sortBy: SortByEnum) {\n  userpools(page: $page, limit: $limit, sortBy: $sortBy) {\n    totalCount\n    list {\n      id\n      name\n      domain\n      ownerId\n      description\n      secret\n      jwtSecret\n      logo\n      createdAt\n      updatedAt\n      emailVerifiedDefault\n      sendWelcomeEmail\n      registerDisabled\n      appSsoEnabled\n      showWxQRCodeWhenRegisterDisabled\n      allowedOrigins\n      tokenExpiresAfter\n      isDeleted\n      packageType\n      useCustomUserStore\n      loginRequireEmailVerified\n      verifyCodeLength\n    }\n  }\n}\n    ";
export declare const UsersDocument = "\n    query users($page: Int, $limit: Int, $sortBy: SortByEnum) {\n  users(page: $page, limit: $limit, sortBy: $sortBy) {\n    totalCount\n    list {\n      id\n      arn\n      userPoolId\n      status\n      username\n      email\n      emailVerified\n      phone\n      phoneVerified\n      unionid\n      openid\n      nickname\n      registerSource\n      photo\n      password\n      oauth\n      token\n      tokenExpiredAt\n      loginsCount\n      lastLogin\n      lastIP\n      signedUp\n      blocked\n      isDeleted\n      device\n      browser\n      company\n      name\n      givenName\n      familyName\n      middleName\n      profile\n      preferredUsername\n      website\n      gender\n      birthdate\n      zoneinfo\n      locale\n      address\n      formatted\n      streetAddress\n      locality\n      region\n      postalCode\n      city\n      province\n      country\n      createdAt\n      updatedAt\n      externalId\n    }\n  }\n}\n    ";
export declare const WhitelistDocument = "\n    query whitelist($type: WhitelistType!) {\n  whitelist(type: $type) {\n    createdAt\n    updatedAt\n    value\n  }\n}\n    ";
